@@ -189,9 +189,9 @@ static GtkTargetEntry advanced_exif_drag_types[] = {
 static gint n_exif_drag_types = 1;
 
 
-static void advanced_exif_dnd_get(GtkWidget *listview, GdkDragContext *context,
-				  GtkSelectionData *selection_data, guint info,
-				  guint time, gpointer data)
+static void advanced_exif_dnd_get(GtkWidget *listview, GdkDragContext *UNUSED(context),
+				  GtkSelectionData *selection_data, guint UNUSED(info),
+				  guint UNUSED(time), gpointer UNUSED(data))
 {
 	//ExifWin *ew = data;
 	GtkTreeSelection *sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(listview));
@@ -211,7 +211,7 @@ static void advanced_exif_dnd_get(GtkWidget *listview, GdkDragContext *context,
 }
 
 
-static void advanced_exif_dnd_begin(GtkWidget *listview, GdkDragContext *context, gpointer data)
+static void advanced_exif_dnd_begin(GtkWidget *listview, GdkDragContext *context, gpointer UNUSED(data))
 {
 	//ExifWin *ew = data;
 	GtkTreeSelection *sel = gtk_tree_view_get_selection(GTK_TREE_VIEW(listview));
@@ -249,9 +249,7 @@ static void advanced_exif_add_column(GtkWidget *listview, const gchar *title, gi
 		gtk_tree_view_column_set_sizing(column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
 		}
 
-#if GTK_CHECK_VERSION(3,0,0)
 	gtk_tree_view_column_set_resizable(column, TRUE);
-#endif
 	gtk_tree_view_column_set_sort_column_id(column, n);
 
 	renderer = gtk_cell_renderer_text_new();
@@ -280,18 +278,25 @@ void advanced_exif_close(ExifWin *ew)
 	if (!ew) return;
 
 	advanced_exif_window_get_geometry(ew);
+	file_data_unref(ew->fd);
 
 	gtk_widget_destroy(ew->window);
+
+	g_free(ew);
 }
 
-static void advanced_exif_delete_cb(GtkWidget *widget, GdkEvent *event, gpointer data)
+static gboolean advanced_exif_delete_cb(GtkWidget *UNUSED(widget), GdkEvent *UNUSED(event), gpointer data)
 {
 	ExifWin *ew = data;
 
-	advanced_exif_window_get_geometry(ew);
+	if (!ew) return FALSE;
 
+	advanced_exif_window_get_geometry(ew);
 	file_data_unref(ew->fd);
+
 	g_free(ew);
+
+	return FALSE;
 }
 
 static gint advanced_exif_sort_cb(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer data)
@@ -335,8 +340,8 @@ static gint advanced_exif_sort_cb(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIt
 	return ret;
 }
 
-static gboolean advanced_exif_mouseclick(GtkWidget *widget,
-						GdkEventButton *bevent, gpointer data)
+static gboolean advanced_exif_mouseclick(GtkWidget *UNUSED(widget),
+						GdkEventButton *UNUSED(bevent), gpointer data)
 {
 	ExifWin *ew = data;
 	GtkTreePath *path;
@@ -363,12 +368,14 @@ static gboolean advanced_exif_mouseclick(GtkWidget *widget,
 
 		g_list_free(cols);
 		g_free(value);
+
+		gtk_tree_view_set_search_column(GTK_TREE_VIEW(ew->listview), gtk_tree_view_column_get_sort_column_id(column));
 		}
 
 	return TRUE;
 }
 
-static gboolean advanced_exif_keypress(GtkWidget *widget, GdkEventKey *event, gpointer data)
+static gboolean advanced_exif_keypress(GtkWidget *UNUSED(widget), GdkEventKey *event, gpointer data)
 {
 	ExifWin *ew = data;
 	gboolean stop_signal = FALSE;
@@ -392,6 +399,30 @@ static gboolean advanced_exif_keypress(GtkWidget *widget, GdkEventKey *event, gp
 	return stop_signal;
 } // static gboolean advanced_exif_...
 
+static gboolean search_function_cb(GtkTreeModel *model, gint column, const gchar *key, GtkTreeIter *iter, gpointer UNUSED(data))
+{
+	gboolean ret = TRUE;
+	gchar *field_contents;
+	gchar *field_contents_nocase;
+	gchar *key_nocase;
+
+	gtk_tree_model_get(model, iter, column, &field_contents, -1);
+
+	field_contents_nocase = g_utf8_casefold(field_contents, -1);
+	key_nocase = g_utf8_casefold(key, -1);
+
+	if (g_strstr_len(field_contents_nocase, -1, key_nocase))
+		{
+		ret = FALSE;
+		}
+
+	g_free(field_contents);
+	g_free(field_contents_nocase);
+	g_free(key_nocase);
+
+	return ret;
+}
+
 GtkWidget *advanced_exif_new(LayoutWindow *lw)
 {
 	ExifWin *ew;
@@ -421,21 +452,18 @@ GtkWidget *advanced_exif_new(LayoutWindow *lw)
 	g_object_set_data(G_OBJECT(ew->window), "advanced_exif_data", ew);
 	g_signal_connect(G_OBJECT(ew->window), "delete_event", G_CALLBACK(advanced_exif_delete_cb), ew);
 
-	ew->vbox = gtk_vbox_new(FALSE, PREF_PAD_GAP);
+	ew->vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, PREF_PAD_GAP);
 	gtk_container_add(GTK_CONTAINER(ew->window), ew->vbox);
 	gtk_widget_show(ew->vbox);
 
-	box = gtk_hbox_new(FALSE, 0);
+	box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 
 	ew->label_file_name = gtk_label_new("");
 	gtk_label_set_ellipsize(GTK_LABEL(ew->label_file_name), PANGO_ELLIPSIZE_START);
 	gtk_label_set_selectable(GTK_LABEL(ew->label_file_name), TRUE);
-#if GTK_CHECK_VERSION(3,16,0)
 	gtk_label_set_xalign(GTK_LABEL(ew->label_file_name), 0.5);
 	gtk_label_set_yalign(GTK_LABEL(ew->label_file_name), 0.5);
-#else
-	gtk_misc_set_alignment(GTK_MISC(ew->label_file_name), 0.5, 0.5);
-#endif
+
 	gtk_box_pack_start(GTK_BOX(box), ew->label_file_name, TRUE, TRUE, 0);
 	gtk_widget_show(ew->label_file_name);
 
@@ -469,6 +497,9 @@ GtkWidget *advanced_exif_new(LayoutWindow *lw)
 	advanced_exif_add_column(ew->listview, _("Format"), EXIF_ADVCOL_FORMAT, FALSE);
 	advanced_exif_add_column(ew->listview, _("Elements"), EXIF_ADVCOL_ELEMENTS, FALSE);
 
+	gtk_tree_view_set_enable_search(GTK_TREE_VIEW(ew->listview), TRUE);
+	gtk_tree_view_set_search_column(GTK_TREE_VIEW(ew->listview), EXIF_ADVCOL_DESCRIPTION);
+	gtk_tree_view_set_search_equal_func(GTK_TREE_VIEW(ew->listview), search_function_cb, ew, NULL);
 
 	gtk_drag_source_set(ew->listview,
 			   GDK_BUTTON1_MASK | GDK_BUTTON2_MASK,
