@@ -39,6 +39,8 @@
 #include "rcfile.h"
 #include "bar_gps.h"
 
+#include <gdk/gdkkeysyms.h>
+
 typedef struct _KnownPanes KnownPanes;
 struct _KnownPanes
 {
@@ -96,7 +98,7 @@ static const gchar default_config_rating[] =
 "<gq>"
 "    <layout id = '_current_'>"
 "        <bar>"
-"            <pane_comment id = 'rating' expanded = 'true' key = '" RATING_KEY "' height = '10' />"
+"            <pane_rating id = 'rating' expanded = 'true' />"
 "        </bar>"
 "    </layout>"
 "</gq>";
@@ -184,7 +186,7 @@ static const gchar default_config_gps[] =
 "    <layout id = '_current_'>"
 "        <bar>"
 "            <pane_gps id = 'gps' expanded = 'true'"
-"                      map-id = 'osm::mapnik'"
+"                      map-id = 'osm-mapnik'"
 "                      zoom-level = '8'"
 "                      latitude = '50116666'"
 "                      longitude = '8683333' />"
@@ -200,7 +202,7 @@ static const KnownPanes known_panes[] = {
 	{PANE_COMMENT,		"title",	N_("Title"),		default_config_title},
 	{PANE_KEYWORDS,		"keywords",	N_("Keywords"),		default_config_keywords},
 	{PANE_COMMENT,		"comment",	N_("Comment"),		default_config_comment},
-	{PANE_COMMENT,		"rating",	N_("Rating"),		default_config_rating},
+	{PANE_RATING,		"rating",	N_("Star Rating"),	default_config_rating},
 	{PANE_COMMENT,		"headline",	N_("Headline"),		default_config_headline},
 	{PANE_EXIF,		"exif",		N_("Exif"),		default_config_exif},
 /* other pre-configured panes */
@@ -228,7 +230,7 @@ struct _BarData
 	gint width;
 };
 
-static void bar_expander_move(GtkWidget *widget, gpointer data, gboolean up, gboolean single_step)
+static void bar_expander_move(GtkWidget *UNUSED(widget), gpointer data, gboolean up, gboolean single_step)
 {
 	GtkWidget *expander = data;
 	GtkWidget *box;
@@ -274,13 +276,73 @@ static void bar_expander_move_bottom_cb(GtkWidget *widget, gpointer data)
 	bar_expander_move(widget, data, FALSE, FALSE);
 }
 
-static void bar_expander_delete_cb(GtkWidget *widget, gpointer data)
+static void height_spin_changed_cb(GtkSpinButton *spin, gpointer data)
+{
+
+	gtk_widget_set_size_request(GTK_WIDGET(data), -1, gtk_spin_button_get_value_as_int(spin));
+}
+
+static gboolean height_spin_key_press_cb(GtkWidget *UNUSED(widget), GdkEventKey *event, gpointer data)
+{
+	if ((event->keyval == GDK_KEY_Return || event->keyval == GDK_KEY_Escape))
+		{
+		gtk_widget_destroy(GTK_WIDGET(data));
+		}
+
+	return TRUE;
+}
+
+static void bar_expander_height_cb(GtkWidget *UNUSED(widget), gpointer data)
+{
+	GtkWidget *expander = data;
+	GtkWidget *spin;
+	GtkWidget *window;
+	GtkWidget *data_box;
+	GList *list;
+	gint x, y;
+	gint w, h;
+	GdkDisplay *display;
+	GdkDeviceManager *device_manager;
+	GdkDevice *device;
+
+	display = gdk_display_get_default();
+	device_manager = gdk_display_get_device_manager(display);
+	device = gdk_device_manager_get_client_pointer(device_manager);
+	gdk_device_get_position(device, NULL, &x, &y);
+
+	list = gtk_container_get_children(GTK_CONTAINER(expander));
+	data_box = list->data;
+
+	window = gtk_window_new(GTK_WINDOW_POPUP);
+
+	gtk_window_set_modal(GTK_WINDOW(window), TRUE);
+	gtk_window_set_keep_above(GTK_WINDOW(window), TRUE);
+	gtk_window_set_default_size(GTK_WINDOW(window), 50, 30); //** @FIXME set these values in a more sensible way */
+
+	gtk_window_move(GTK_WINDOW(window), x, y);
+	gtk_widget_show(window);
+
+	gtk_widget_get_size_request(GTK_WIDGET(data_box), &w, &h);
+
+	spin = gtk_spin_button_new_with_range(1, 1000, 1);
+	g_signal_connect(G_OBJECT(spin), "value-changed", G_CALLBACK(height_spin_changed_cb), data_box);
+	g_signal_connect(G_OBJECT(spin), "key-press-event", G_CALLBACK(height_spin_key_press_cb), window);
+
+	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin), h);
+	gtk_container_add(GTK_CONTAINER(window), spin);
+	gtk_widget_show(spin);
+	gtk_widget_grab_focus(GTK_WIDGET(spin));
+
+	g_list_free(list);
+}
+
+static void bar_expander_delete_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	GtkWidget *expander = data;
 	gtk_widget_destroy(expander);
 }
 
-static void bar_expander_add_cb(GtkWidget *widget, gpointer data)
+static void bar_expander_add_cb(GtkWidget *widget, gpointer UNUSED(data))
 {
 	//GtkWidget *bar = data;
 	const KnownPanes *pane = known_panes;
@@ -307,8 +369,17 @@ static void bar_menu_popup(GtkWidget *widget)
 	GtkWidget *menu;
 	GtkWidget *bar;
 	GtkWidget *expander;
-	const KnownPanes *pane = known_panes;
 	BarData *bd;
+	gboolean display_height_option = FALSE;
+	gchar const *label;
+
+	label = gtk_expander_get_label(GTK_EXPANDER(widget));
+	display_height_option =	(g_strcmp0(label, "Comment") == 0) ||
+							(g_strcmp0(label, "Rating") == 0) ||
+							(g_strcmp0(label, "Title") == 0) ||
+							(g_strcmp0(label, "Headline") == 0) ||
+							(g_strcmp0(label, "Keywords") == 0) ||
+							(g_strcmp0(label, "GPS Map") == 0);
 
 	bd = g_object_get_data(G_OBJECT(widget), "bar_data");
 	if (bd)
@@ -334,18 +405,17 @@ static void bar_menu_popup(GtkWidget *widget)
 		menu_item_add_stock(menu, _("Move _down"), GTK_STOCK_GO_DOWN, G_CALLBACK(bar_expander_move_down_cb), expander);
 		menu_item_add_stock(menu, _("Move to _bottom"), GTK_STOCK_GOTO_BOTTOM, G_CALLBACK(bar_expander_move_bottom_cb), expander);
 		menu_item_add_divider(menu);
+
+		if (gtk_expander_get_expanded(GTK_EXPANDER(expander)) && display_height_option)
+			{
+			menu_item_add_stock(menu, _("Height..."), GTK_STOCK_PREFERENCES, G_CALLBACK(bar_expander_height_cb), expander);
+			menu_item_add_divider(menu);
+			}
+
 		menu_item_add_stock(menu, _("Remove"), GTK_STOCK_DELETE, G_CALLBACK(bar_expander_delete_cb), expander);
 		menu_item_add_divider(menu);
 		}
 
-	while (pane->id)
-		{
-		GtkWidget *item;
-		item = menu_item_add_stock(menu, _(pane->title), GTK_STOCK_ADD, G_CALLBACK(bar_expander_add_cb), bar);
-		g_object_set_data(G_OBJECT(item), "pane_add_id", pane->id);
-		pane++;
-		}
-
 	gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, bar, 0, GDK_CURRENT_TIME);
 }
 
@@ -371,7 +441,7 @@ static void bar_menu_add_popup(GtkWidget *widget)
 }
 
 
-static gboolean bar_menu_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer data)
+static gboolean bar_menu_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer UNUSED(data))
 {
 	if (bevent->button == MOUSE_BUTTON_RIGHT)
 		{
@@ -381,7 +451,7 @@ static gboolean bar_menu_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer
 	return FALSE;
 }
 
-static void bar_expander_cb(GObject *object, GParamSpec *param_spec, gpointer data)
+static void bar_expander_cb(GObject *object, GParamSpec *UNUSED(param_spec), gpointer UNUSED(data))
 {
 	GtkExpander *expander;
 	GtkWidget *child;
@@ -399,7 +469,7 @@ static void bar_expander_cb(GObject *object, GParamSpec *param_spec, gpointer da
 		}
 }
 
-static gboolean bar_menu_add_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer data)
+static gboolean bar_menu_add_cb(GtkWidget *widget, GdkEventButton *UNUSED(bevent), gpointer UNUSED(data))
 {
 	bar_menu_add_popup(widget);
 	return TRUE;
@@ -611,7 +681,7 @@ void bar_add(GtkWidget *bar, GtkWidget *pane)
 
 }
 
-void bar_populate_default(GtkWidget *bar)
+void bar_populate_default(GtkWidget *UNUSED(bar))
 {
 	const gchar *populate_id[] = {"histogram", "title", "keywords", "comment", "rating", "exif", NULL};
 	const gchar **id = populate_id;
@@ -624,11 +694,11 @@ void bar_populate_default(GtkWidget *bar)
 		}
 }
 
-static void bar_size_allocate(GtkWidget *widget, GtkAllocation *allocation, gpointer data)
+static void bar_size_allocate(GtkWidget *UNUSED(widget), GtkAllocation *UNUSED(allocation), gpointer data)
 {
 	BarData *bd = data;
 
-	bd->width = allocation->width;
+	bd->width = gtk_paned_get_position(GTK_PANED(bd->lw->utility_paned));
 }
 
 gint bar_get_width(GtkWidget *bar)
@@ -651,7 +721,7 @@ void bar_close(GtkWidget *bar)
 	gtk_widget_destroy(bd->widget);
 }
 
-static void bar_destroy(GtkWidget *widget, gpointer data)
+static void bar_destroy(GtkWidget *UNUSED(widget), gpointer data)
 {
 	BarData *bd = data;
 
@@ -660,14 +730,14 @@ static void bar_destroy(GtkWidget *widget, gpointer data)
 }
 
 #ifdef HAVE_LIBCHAMPLAIN_GTK
-/*
-   FIXME: this is an ugly hack that works around this bug:
+/**
+   @FIXME this is an ugly hack that works around this bug:
    https://bugzilla.gnome.org/show_bug.cgi?id=590692
    http://bugzilla.openedhand.com/show_bug.cgi?id=1751
    it should be removed as soon as a better solution exists
 */
 
-static void bar_unrealize_clutter_fix_cb(GtkWidget *widget, gpointer data)
+static void bar_unrealize_clutter_fix_cb(GtkWidget *widget, gpointer UNUSED(data))
 {
 	GtkWidget *child = gtk_bin_get_child(GTK_BIN(widget));
 	if (child) gtk_widget_unrealize(child);
@@ -686,7 +756,7 @@ GtkWidget *bar_new(LayoutWindow *lw)
 
 	bd->lw = lw;
 
-	bd->widget = gtk_vbox_new(FALSE, PREF_PAD_GAP);
+	bd->widget = gtk_box_new(GTK_ORIENTATION_VERTICAL, PREF_PAD_GAP);
 	DEBUG_NAME(bd->widget);
 	g_object_set_data(G_OBJECT(bd->widget), "bar_data", bd);
 	g_signal_connect(G_OBJECT(bd->widget), "destroy",
@@ -698,15 +768,16 @@ GtkWidget *bar_new(LayoutWindow *lw)
 	g_signal_connect(G_OBJECT(bd->widget), "button_release_event", G_CALLBACK(bar_menu_cb), bd);
 
 	bd->width = SIDEBAR_DEFAULT_WIDTH;
-	gtk_widget_set_size_request(bd->widget, bd->width, -1);
 
-	box = gtk_hbox_new(FALSE, 0);
+	box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	DEBUG_NAME(box);
 
 	bd->label_file_name = gtk_label_new("");
 	gtk_label_set_ellipsize(GTK_LABEL(bd->label_file_name), PANGO_ELLIPSIZE_END);
 	gtk_label_set_selectable(GTK_LABEL(bd->label_file_name), TRUE);
-	gtk_misc_set_alignment(GTK_MISC(bd->label_file_name), 0.5, 0.5);
+	gtk_label_set_xalign(GTK_LABEL(bd->label_file_name), 0.5);
+	gtk_label_set_yalign(GTK_LABEL(bd->label_file_name), 0.5);
+
 	gtk_box_pack_start(GTK_BOX(box), bd->label_file_name, TRUE, TRUE, 0);
 	gtk_widget_show(bd->label_file_name);
 
@@ -721,11 +792,11 @@ GtkWidget *bar_new(LayoutWindow *lw)
 	gtk_widget_show(scrolled);
 
 
-	bd->vbox = gtk_vbox_new(FALSE, 0);
-	gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrolled), bd->vbox);
+	bd->vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+	gtk_container_add(GTK_CONTAINER(scrolled), bd->vbox);
 	gtk_viewport_set_shadow_type(GTK_VIEWPORT(gtk_bin_get_child(GTK_BIN(scrolled))), GTK_SHADOW_NONE);
 
-	add_box = gtk_vbox_new(FALSE, 0);
+	add_box = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	DEBUG_NAME(add_box);
 	gtk_box_pack_end(GTK_BOX(bd->widget), add_box, FALSE, FALSE, 0);
 	tbar = pref_toolbar_new(add_box, GTK_TOOLBAR_ICONS);
@@ -744,7 +815,7 @@ GtkWidget *bar_new(LayoutWindow *lw)
 }
 
 
-GtkWidget *bar_update_from_config(GtkWidget *bar, const gchar **attribute_names, const gchar **attribute_values)
+GtkWidget *bar_update_from_config(GtkWidget *bar, const gchar **attribute_names, const gchar **attribute_values, LayoutWindow *lw)
 {
 	gboolean enabled = TRUE;
 	gint width = SIDEBAR_DEFAULT_WIDTH;
@@ -761,16 +832,8 @@ GtkWidget *bar_update_from_config(GtkWidget *bar, const gchar **attribute_names,
 		log_printf("unknown attribute %s = %s\n", option, value);
 		}
 
-#if !GTK_CHECK_VERSION(3,0,0)
-/* FIXME: In bar_size_allocate() the width obained is the allocated width. In GTK2 this
- * is the actual width. In GTK3 it is the *minimum* width.
- * This results in the info sidebar being able to increase, but not
- * decrease. There does not seem to be a way in GTK3 to get the actual width of
- * a widget. For GTK3 the only way is to disable it. The width of the sidebar
- * is therefore not preserved across restarts.
- */
-	gtk_widget_set_size_request(bar, width, -1);
-#endif
+	gtk_paned_set_position(GTK_PANED(lw->utility_paned), width);
+
 	if (enabled)
 		{
 		gtk_widget_show(bar);
@@ -785,7 +848,7 @@ GtkWidget *bar_update_from_config(GtkWidget *bar, const gchar **attribute_names,
 GtkWidget *bar_new_from_config(LayoutWindow *lw, const gchar **attribute_names, const gchar **attribute_values)
 {
 	GtkWidget *bar = bar_new(lw);
-	return bar_update_from_config(bar, attribute_names, attribute_values);
+	return bar_update_from_config(bar, attribute_names, attribute_values, lw);
 }
 
 GtkWidget *bar_pane_expander_title(const gchar *title)
@@ -793,7 +856,8 @@ GtkWidget *bar_pane_expander_title(const gchar *title)
 	GtkWidget *widget = gtk_label_new(title);
 
 	pref_label_bold(widget, TRUE, FALSE);
-	//gtk_label_set_ellipsize(GTK_LABEL(widget), PANGO_ELLIPSIZE_END); //FIXME: do not work
+	//gtk_label_set_ellipsize(GTK_LABEL(widget), PANGO_ELLIPSIZE_END);
+	/** @FIXME do not work */
 
 	return widget;
 }
