@@ -41,7 +41,7 @@ enum {
 static gboolean collection_save_confirmed(FileDialog *fd, gboolean overwrite, CollectionData *cd);
 
 
-static void collection_confirm_ok_cb(GenericDialog *gd, gpointer data)
+static void collection_confirm_ok_cb(GenericDialog *UNUSED(gd), gpointer data)
 {
 	FileDialog *fd = data;
 	CollectionData *cd = GENERIC_DIALOG(fd)->data;
@@ -53,7 +53,7 @@ static void collection_confirm_ok_cb(GenericDialog *gd, gpointer data)
 		}
 }
 
-static void collection_confirm_cancel_cb(GenericDialog *gd, gpointer data)
+static void collection_confirm_cancel_cb(GenericDialog *UNUSED(gd), gpointer UNUSED(data))
 {
 	/* this is a no-op, so the cancel button is added */
 }
@@ -111,7 +111,7 @@ static void collection_save_cb(FileDialog *fd, gpointer data)
 
 	path = fd->dest_path;
 
-	/* FIXME: utf8 */
+	/** @FIXME utf8 */
 	if (!file_extension_match(path, GQ_COLLECTION_EXT))
 		{
 		gchar *buf;
@@ -156,7 +156,7 @@ static void real_collection_button_pressed(FileDialog *fd, gpointer data, gint a
 
 	if (append)
 		{
-		collection_load(cd, fd->dest_path, TRUE);
+		collection_load(cd, fd->dest_path, COLLECTION_LOAD_APPEND);
 		collection_unref(cd);
 		}
 	else
@@ -202,14 +202,14 @@ static void collection_save_or_load_dialog(const gchar *path,
 		if (!cd) return;
 		title = _("Save collection");
 		btntext = NULL;
-		btnfunc = collection_save_cb;
+		btnfunc = (gpointer)collection_save_cb;
 		stock_id = GTK_STOCK_SAVE;
 		}
 	else if (type == DIALOG_LOAD)
 		{
 		title = _("Open collection");
 		btntext = NULL;
-		btnfunc = collection_load_cb;
+		btnfunc = (gpointer)collection_load_cb;
 		stock_id = GTK_STOCK_OPEN;
 		}
 	else
@@ -217,7 +217,7 @@ static void collection_save_or_load_dialog(const gchar *path,
 		if (!cd) return;
 		title = _("Append collection");
 		btntext = _("_Append");
-		btnfunc = collection_append_cb;
+		btnfunc = (gpointer)collection_append_cb;
 		stock_id = GTK_STOCK_ADD;
 		}
 
@@ -230,7 +230,7 @@ static void collection_save_or_load_dialog(const gchar *path,
 			     collection_save_or_load_dialog_close_cb, cd);
 
 	generic_dialog_add_message(GENERIC_DIALOG(fd), NULL, title, NULL, FALSE);
-	file_dialog_add_button(fd, stock_id, btntext, btnfunc, TRUE);
+	file_dialog_add_button(fd, stock_id, btntext, (void (*)(FileDialog *, gpointer))btnfunc, TRUE);
 
 	file_dialog_add_path_widgets(fd, get_collections_dir(), path,
 				     "collection_load_save", GQ_COLLECTION_EXT, _("Collection Files"));
