@@ -17,9 +17,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
+#include <config.h>
 
 #define _XOPEN_SOURCE
 
@@ -660,6 +658,11 @@ static void zd_tz(ZoneDetectResult *results, gchar **timezone, gchar **countryna
 	g_free(timezone_id);
 }
 
+void ZoneDetect_onError(int errZD, int errNative)
+{
+	log_printf("Error: ZoneDetect %s (0x%08X)\n", ZDGetErrorString(errZD), (unsigned)errNative);
+}
+
 /**
  * @brief Gets timezone data from an exif structure
  * @param[in] exif
@@ -689,8 +692,6 @@ static gboolean exif_build_tz_data(ExifData *exif, gchar **exif_date_time, gchar
 	ZoneDetect *cd;
 	ZoneDetectResult *results;
 	gboolean ret = FALSE;
-	gchar *basename;
-	gchar *path;
 
 	text_latitude = exif_get_data_as_text(exif, "Exif.GPSInfo.GPSLatitude");
 	text_longitude = exif_get_data_as_text(exif, "Exif.GPSInfo.GPSLongitude");
@@ -724,11 +725,10 @@ static gboolean exif_build_tz_data(ExifData *exif, gchar **exif_date_time, gchar
 			longitude = -longitude;
 			}
 
-		path = path_from_utf8(TIMEZONE_DATABASE);
-		basename = g_path_get_basename(path);
-		timezone_path = g_build_filename(get_rc_dir(), basename, NULL);
+		timezone_path = g_build_filename(get_rc_dir(), TIMEZONE_DATABASE_FILE, NULL);
 		if (g_file_test(timezone_path, G_FILE_TEST_EXISTS))
 			{
+			ZDSetErrorHandler(ZoneDetect_onError);
 			cd = ZDOpenDatabase(timezone_path);
 			if (cd)
 				{
@@ -745,9 +745,7 @@ static gboolean exif_build_tz_data(ExifData *exif, gchar **exif_date_time, gchar
 				}
 			ZDCloseDatabase(cd);
 			}
-		g_free(path);
 		g_free(timezone_path);
-		g_free(basename);
 		}
 
 	if (ret && text_date && text_time)
@@ -1148,7 +1146,7 @@ gboolean exif_jpeg_parse_color(ExifData *exif, guchar *data, guint size)
  * it is here because it shares tag neming infrastructure with exif
  * we should probably not invest too much effort into this because
  * new exiv2 will support the same functionality
- * http://dev.exiv2.org/issues/show/505
+ * https://dev.exiv2.org/issues/505
  *-------------------------------------------------------------------
  */
 
@@ -1189,7 +1187,7 @@ static gchar *mode_number(mode_t m)
 	return g_strdup_printf("%s (%d%d%d%d)", pbuf, mb, mu, mg, mo);
 }
 
-gchar *metadata_file_info(FileData *fd, const gchar *key, MetadataFormat format)
+gchar *metadata_file_info(FileData *fd, const gchar *key, MetadataFormat UNUSED(format))
 {
 	gchar *page_n_of_m;
 
@@ -1241,7 +1239,7 @@ gchar *metadata_file_info(FileData *fd, const gchar *key, MetadataFormat format)
 }
 
 #ifdef HAVE_LUA
-gchar *metadata_lua_info(FileData *fd, const gchar *key, MetadataFormat format)
+gchar *metadata_lua_info(FileData *fd, const gchar *key, MetadataFormat UNUSED(format))
 {
 	gchar *script_name;
 	gchar *script_name_utf8;
