@@ -20,9 +20,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
+#include <config.h>
 
 #ifndef HAVE_EXIV2
 
@@ -177,7 +175,7 @@ EXIF_MARKER_LIST_END
 
 
 gboolean format_fuji_makernote(ExifData *exif, guchar *tiff, guint offset,
-			       guint size, ExifByteOrder bo)
+			       guint size, ExifByteOrder UNUSED(bo))
 {
 	guchar *data;
 	guint ifdstart;
@@ -203,7 +201,8 @@ gboolean format_fuji_makernote(ExifData *exif, guchar *tiff, guint offset,
 
 	return TRUE;
 }
-
+#else
+typedef int dummy_variable;
 #endif
 /* not HAVE_EXIV2 */
 /* vim: set shiftwidth=8 softtabstop=0 cindent cinoptions={1s: */
