@@ -1,20 +1,25 @@
 /*
- * Geeqie
- * (C) 2005 John Ellis
- * Copyright (C) 2008 - 2012 The Geeqie Team
+ * Copyright (C) 2005 John Ellis
+ * Copyright (C) 2008 - 2016 The Geeqie Team
  *
- *  Authors:
- *    Raw NEF jpeg extraction based on nefextract.c by Joseph Heled,
- *        in addition nefextract.c is based on dcraw by Dave Coffin.
+ * Author: Joseph Heled
  *
- * This software is released under the GNU General Public License (GNU GPL).
- * Please read the included file COPYING for more information.
- * This software comes with no warranty of any kind, use at your own risk!
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
+#include <config.h>
 
 #ifndef HAVE_EXIV2
 
@@ -132,7 +137,7 @@ static guint nikon_tiff_table(guchar *data, const guint len, guint offset, ExifB
 }
 
 gboolean format_nikon_raw(guchar *data, const guint len,
-		          guint *image_offset, guint *exif_offset)
+		          guint *image_offset, guint *UNUSED(exif_offset))
 {
 	guint i_off = 0;
 	guint i_len = 0;
@@ -405,7 +410,7 @@ gboolean format_nikon_makernote(ExifData *exif, guchar *tiff, guint offset,
 		ExifItem *shadow;
 
 		shadow = exif_item_new(marker.format, marker.tag, 1, &marker);
-		memcpy(shadow->data, item->data + 2, 2);
+		memcpy(shadow->data, (char *)item->data + 2, 2);
 
 		exif->items = g_list_prepend(exif->items, shadow);
 		}
@@ -426,6 +431,8 @@ gboolean format_nikon_makernote(ExifData *exif, guchar *tiff, guint offset,
 	return TRUE;
 }
 
+#else
+typedef int dummy_variable;
 #endif
 /* not HAVE_EXIV2 */
 /* vim: set shiftwidth=8 softtabstop=0 cindent cinoptions={1s: */
