@@ -52,69 +52,6 @@
 #define IMAGE_LOADER_READ_BUFFER_SIZE_DEFAULT 	4096
 #define IMAGE_LOADER_IDLE_READ_LOOP_COUNT_DEFAULT 	1
 
-/**
- * @page diagrams Diagrams
- * @section image_load_overview Image Load Overview
- * @startuml
- * object image_change
- * object image_change_complete
- * object image_load_begin
- * object image_loader_start
- * object image_loader_start_thread
- * object image_loader_start_idle
- * object image_loader_setup_source
- * object image_loader_thread_run
- * object image_loader_begin
- * object image_loader_setuploader
- * circle "il->memory_mapped"
- * object exif_get_preview_
- * object exif_get_preview
- * object libraw_get_preview
- * 
- * image_change : image.c
- * image_change_complete : image.c
- * image_load_begin : image.c
- * image_loader_start : image_load.c
- * image_loader_start_thread : image_load.c
- * image_loader_start_idle : image_load.c
- * image_loader_thread_run : image_load.c
- * image_loader_begin : image_load.c
- * image_loader_setuploader : image_load.c
- * image_loader_setuploader : -
- * image_loader_setuploader : Select backend using magic
- * image_loader_setup_source : image_load.c
- * exif_get_preview : exiv2.cc
- * exif_get_preview : EXIV2_TEST_VERSION(0,17,90)
- * exif_get_preview_ : exif.c
- * exif_get_preview_ : -
- * exif_get_preview_ : If exiv2 not installed
- * libraw_get_preview : image_load_libraw.c
- * 
- * image_change --> image_change_complete
- * image_change_complete --> image_load_begin
- * image_load_begin --> image_loader_start
- * image_loader_start --> image_loader_start_thread
- * image_loader_start --> image_loader_start_idle : Obsolete - no threads version
- * image_loader_start_thread --> image_loader_thread_run
- * image_loader_start_thread --> image_loader_setup_source
- * image_loader_setup_source --> exif_get_preview_
- * image_loader_setup_source --> exif_get_preview
- * image_loader_setup_source --> libraw_get_preview : Try libraw if exiv2 fails
- * exif_get_preview_ ..> "il->memory_mapped"
- * exif_get_preview ..> "il->memory_mapped"
- * libraw_get_preview ..> "il->memory_mapped"
- * image_loader_thread_run --> image_loader_begin
- * image_loader_begin --> image_loader_setuploader
- * "il->memory_mapped" ..> image_loader_setuploader
- * note left of "il->memory_mapped" : Points to first byte of embedded jpeg (#FFD8)\n if preview found, otherwise to first byte of file
- * @enduml
- */
- /**
-  * @file
-  * @ref image_load_overview "Image Load Overview"
-  */
-  
-/**************************************************************************************/
 /* image loader class */
 
 
@@ -157,7 +94,7 @@ GType image_loader_get_type(void)
 	return type;
 }
 
-static void image_loader_init(GTypeInstance *instance, gpointer g_class)
+static void image_loader_init(GTypeInstance *instance, gpointer UNUSED(g_class))
 {
 	ImageLoader *il = (ImageLoader *)instance;
 
@@ -185,21 +122,15 @@ static void image_loader_init(GTypeInstance *instance, gpointer g_class)
 
 	il->can_destroy = TRUE;
 
-#ifdef HAVE_GTHREAD
-#if GLIB_CHECK_VERSION(2,32,0)
 	il->data_mutex = g_new(GMutex, 1);
 	g_mutex_init(il->data_mutex);
 	il->can_destroy_cond = g_new(GCond, 1);
 	g_cond_init(il->can_destroy_cond);
-#else
-	il->data_mutex = g_mutex_new();
-	il->can_destroy_cond = g_cond_new();
-#endif
-#endif
-	DEBUG_1("new image loader %p, bufsize=%" G_GSIZE_FORMAT " idle_loop=%u", il, il->read_buffer_size, il->idle_read_loop_count);
+
+	DEBUG_1("new image loader %p, bufsize=%" G_GSIZE_FORMAT " idle_loop=%u", (void *)il, il->read_buffer_size, il->idle_read_loop_count);
 }
 
-static void image_loader_class_init_wrapper(void *data, void *user_data)
+static void image_loader_class_init_wrapper(void *data, void *UNUSED(user_data))
 {
 	image_loader_class_init(data);
 }
@@ -276,7 +207,7 @@ static void image_loader_finalize(GObject *object)
 
 	if (il->error) DEBUG_1("%s", image_loader_get_error(il));
 
-	DEBUG_1("freeing image loader %p bytes_read=%" G_GSIZE_FORMAT, il, il->bytes_read);
+	DEBUG_1("freeing image loader %p bytes_read=%" G_GSIZE_FORMAT, (void *)il, il->bytes_read);
 
 	if (il->idle_done_id)
 		{
@@ -308,17 +239,11 @@ static void image_loader_finalize(GObject *object)
 	if (il->error) g_error_free(il->error);
 
 	file_data_unref(il->fd);
-#ifdef HAVE_GTHREAD
-#if GLIB_CHECK_VERSION(2,32,0)
+
 	g_mutex_clear(il->data_mutex);
 	g_free(il->data_mutex);
 	g_cond_clear(il->can_destroy_cond);
 	g_free(il->can_destroy_cond);
-#else
-	g_mutex_free(il->data_mutex);
-	g_cond_free(il->can_destroy_cond);
-#endif
-#endif
 }
 
 void image_loader_free(ImageLoader *il)
@@ -547,7 +472,7 @@ static void image_loader_sync_pixbuf(ImageLoader *il)
 	g_mutex_unlock(il->data_mutex);
 }
 
-static void image_loader_area_updated_cb(gpointer loader,
+static void image_loader_area_updated_cb(gpointer UNUSED(loader),
 				 guint x, guint y, guint w, guint h,
 				 gpointer data)
 {
@@ -581,8 +506,8 @@ static void image_loader_area_prepared_cb(gpointer loader, gpointer data)
 	size_t h, rs;
 
 	/* a workaround for
-	   http://bugzilla.gnome.org/show_bug.cgi?id=547669
-	   http://bugzilla.gnome.org/show_bug.cgi?id=589334
+	   https://bugzilla.gnome.org/show_bug.cgi?id=547669
+	   https://bugzilla.gnome.org/show_bug.cgi?id=589334
 	*/
 	gchar *format = il->backend.get_format_name(loader);
 	if (strcmp(format, "svg") == 0 ||
@@ -1278,7 +1203,6 @@ static gboolean image_loader_start_idle(ImageLoader *il)
 /**************************************************************************************/
 /* execution via thread */
 
-#ifdef HAVE_GTHREAD
 static GThreadPool *image_loader_thread_pool = NULL;
 
 static GCond *image_loader_prio_cond = NULL;
@@ -1313,7 +1237,7 @@ static void image_loader_thread_wait_high(void)
 }
 
 
-static void image_loader_thread_run(gpointer data, gpointer user_data)
+static void image_loader_thread_run(gpointer data, gpointer UNUSED(user_data))
 {
 	ImageLoader *il = data;
 	gboolean cont;
@@ -1382,15 +1306,10 @@ static gboolean image_loader_start_thread(ImageLoader *il)
         if (!image_loader_thread_pool)
 		{
 		image_loader_thread_pool = g_thread_pool_new(image_loader_thread_run, NULL, -1, FALSE, NULL);
-#if GLIB_CHECK_VERSION(2,32,0)
 		if (!image_loader_prio_cond) image_loader_prio_cond = g_new(GCond, 1);
 		g_cond_init(image_loader_prio_cond);
 		if (!image_loader_prio_mutex) image_loader_prio_mutex = g_new(GMutex, 1);
 		g_mutex_init(image_loader_prio_mutex);
-#else
-		image_loader_prio_cond = g_cond_new();
-		image_loader_prio_mutex = g_mutex_new();
-#endif
 		}
 
 	il->can_destroy = FALSE; /* ImageLoader can't be freed until image_loader_thread_run finishes */
@@ -1400,7 +1319,6 @@ static gboolean image_loader_start_thread(ImageLoader *il)
 
 	return TRUE;
 }
-#endif /* HAVE_GTHREAD */
 
 
 /**************************************************************************************/
@@ -1413,11 +1331,7 @@ gboolean image_loader_start(ImageLoader *il)
 
 	if (!il->fd) return FALSE;
 
-#ifdef HAVE_GTHREAD
 	return image_loader_start_thread(il);
-#else
-	return image_loader_start_idle(il);
-#endif
 }
 
 
