@@ -18,7 +18,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "config.h"
+#include <config.h>
 
 #ifdef HAVE_LUA
 
@@ -84,7 +84,7 @@ static FileData *lua_check_image(lua_State *L, int index)
 /**
  * @brief Get exif structure of selected image
  * @param L 
- * @returns An @ref ExifData data structure containing the entire exif data
+ * @returns An #ExifData data structure containing the entire exif data
  * 
  * To be used in conjunction with @link lua_exif_get_datum <exif-structure>:get_datum() @endlink
  */
@@ -425,6 +425,7 @@ gchar *lua_callvalue(FileData *fd, const gchar *file, const gchar *function)
 		} // if (error) { ... } else
 	return data;
 }
-
+#else
+typedef int dummy_variable;
 #endif
 /* vim: set shiftwidth=8 softtabstop=0 cindent cinoptions={1s: */
