@@ -66,203 +66,6 @@
 #include <clutter-gtk/clutter-gtk.h>
 #endif
 
-#ifdef HAVE_GTHREAD
-/** @FIXME see below */
-#include <X11/Xlib.h>
-#endif
-
-/**
- * @page diagrams Diagrams
- * @section options_overview Options Overview
- * 
- * #_ConfOptions  #_LayoutOptions
- * 
- * @startuml
- * 
- * object options.h
- * object typedefs.h
- * 
- * options.h : ConfOptions
- * options.h : \n
- * options.h : Options applicable to **all** Layout Windows
- * options.h : These are in the <global> section of geeqierc.xml
- * options.h : Available to all modules via the global variable **options**
- * typedefs.h : LayoutOptions
- * typedefs.h : \n
- * typedefs.h : Options applicable to **each** Layout Window
- * typedefs.h : These are in the <layout> section of geeqierc.xml
- * typedefs.h : There is one <layout> section for each Layout Window displayed
- * typedefs.h : Available via **<layout_window>->options**
- * 
- * @enduml
- */
-
-/**
- * @page diagrams Diagrams
- * @section options_diagrams_main Options - New Window From Main
- * #main  
- * #init_options  
- * #layout_new_from_default  
- * #load_config_from_file  
- * #load_options  
- * #setup_default_options
- * 
- * @startuml
- * group main.c
- * start
- * group options.c
- * : **init_options()**
- * 
- * Set **options** = ConfOptions from hard-coded init values;
- * end group
- * 
- * group options.c
- * : **setup_default_options()**
- * 
- * set hard-coded ConfOptions:
- * 
- * bookmarks:
- * * dot dir
- * * Home
- * * Desktop
- * * Collections
- * safe delete path
- * OSD template string
- * sidecar extensions
- * shell path and options
- * marks tooltips
- * help search engine;
- * end group
- * 
- * if (first entry
- * or
- * --new-instance) then (yes)
- * group options.c
- * : **load_options()**
- * ;
- * 
- * split
- * : GQ_SYSTEM_WIDE_DIR
- * /geeqierc.xml;
- * split again
- * : XDG_CONFIG_HOME
- * /geeqierc.xml;
- * split again
- * : HOME
- * /.geeqie/geeqierc.xml;
- * end split
- * 
- * group rcfile.c
- * : **load_config_from_file()**
- * 
- * set  **options** from file
- * and all <layout window>->options  in file;
- * end group
- * 
- * end group
- * 
- * if (broken config. file
- * or no config file
- * or no layout section loaded
- * (i.e. session not saved)) then (yes)
- * group layout.c
- * : **layout_new_from_default()**;
- * if (default.xml exists) then (yes)
- * : Load user-saved
- *  layout_window default options
- *  from default.xml file;
- * else (no)
- * : Load hard-coded
- *  layout_window default options;
- * endif
- * end group
- * endif
- * 
- * else (no)
- * : Send --new-window request to remote
- *  No return to this point
- *  This instance terminates;
- * stop
- * endif
- * 
- * : Enter gtk main loop;
- * 
- * end group
- * @enduml
- */
-
-/**
- * @page diagrams Diagrams
- * @section options_diagrams_remote Options - New Window From Remote
- * #layout_new_from_default  
- * @startuml
- * 
- * group remote.c
- * start
- * group layout.c
- * : **layout_new_from_default()**;
- * if (default.xml exists) then (yes)
- * : Load user-saved
- *  layout_window default options
- *  from default.xml file;
- * else (no)
- * : Load hard-coded
- *  layout_window default options;
- * endif
- * end group
- * : set path from PWD;
- * @enduml
- */
-
-/**
- * @page diagrams Diagrams
- * @section options_diagrams_menu Options - New Window From Menu
- * #layout_menu_new_window_cb  
- * #layout_menu_window_from_current_cb  
- * #layout_new_from_default  
- * @startuml
- * 
- * group layout_util.c
- * start
- * 
- * split
- * : default;
- * group layout.c
- * : **layout_new_from_default()**;
- * if (default.xml exists) then (yes)
- * : Load user-saved
- *  layout_window default options
- *  from default.xml file;
- * else (no)
- * : Load hard-coded
- *  layout_window default options;
- * endif
- * end group
- * 
- * split again
- * : from current
- * 
- * **layout_menu_window_from_current_cb()**
- * copy layout_window options
- * from current window;
- * 
- * split again
- * : named
- * 
- * **layout_menu_new_window_cb()**
- * load layout_window options
- * from saved xml file list;
- * end split
- * 
- * end group
- * @enduml
- */
-  /**
-  * @file
-  * @ref options_overview Options Overview
-  */
-
-
 gboolean thumb_format_changed = FALSE;
 static RemoteConnection *remote_connection = NULL;
 
@@ -270,8 +73,8 @@ gchar *gq_prefix;
 gchar *gq_localedir;
 gchar *gq_helpdir;
 gchar *gq_htmldir;
-gchar *gq_app_dir;
-gchar *gq_bin_dir;
+gchar *gq_appdir;
+gchar *gq_bindir;
 gchar *gq_executable_path;
 gchar *desktop_file_template;
 gchar *instance_identifier;
@@ -349,8 +152,8 @@ static void parse_command_line_add_file(const gchar *file_path, gchar **path, gc
 		}
 }
 
-static void parse_command_line_add_dir(const gchar *dir, gchar **path, gchar **file,
-				       GList **list)
+static void parse_command_line_add_dir(const gchar *dir, gchar **UNUSED(path), gchar **UNUSED(file),
+				       GList **UNUSED(list))
 {
 #if 0
 	/* This is broken because file filter is not initialized yet.
@@ -909,7 +712,7 @@ static void process_command_line_for_cache_maintenance_option(gint argc, gchar *
 static void setup_env_path(void)
 {
 	const gchar *old_path = g_getenv("PATH");
-	gchar *path = g_strconcat(gq_bin_dir, ":", old_path, NULL);
+	gchar *path = g_strconcat(gq_bindir, ":", old_path, NULL);
         g_setenv("PATH", path, TRUE);
 	g_free(path);
 }
@@ -1145,13 +948,13 @@ static void exit_program_final(void)
 
 static GenericDialog *exit_dialog = NULL;
 
-static void exit_confirm_cancel_cb(GenericDialog *gd, gpointer data)
+static void exit_confirm_cancel_cb(GenericDialog *gd, gpointer UNUSED(data))
 {
 	exit_dialog = NULL;
 	generic_dialog_close(gd);
 }
 
-static void exit_confirm_exit_cb(GenericDialog *gd, gpointer data)
+static void exit_confirm_exit_cb(GenericDialog *gd, gpointer UNUSED(data))
 {
 	exit_dialog = NULL;
 	generic_dialog_close(gd);
@@ -1195,7 +998,7 @@ static gint exit_confirm_dlg(void)
 	return TRUE;
 }
 
-static void exit_program_write_metadata_cb(gint success, const gchar *dest_path, gpointer data)
+static void exit_program_write_metadata_cb(gint success, const gchar *UNUSED(dest_path), gpointer UNUSED(data))
 {
 	if (success) exit_program();
 }
@@ -1224,7 +1027,7 @@ void exit_program(void)
 /** @FIXME this probably needs some better ifdefs. Please report any compilation problems */
 
 #if defined(SIGBUS) && defined(SA_SIGINFO)
-static void sigbus_handler_cb(int signum, siginfo_t *info, void *context)
+static void sigbus_handler_cb(int UNUSED(signum), siginfo_t *info, void *UNUSED(context))
 {
 	unsigned long pagesize = sysconf(_SC_PAGE_SIZE);
 	DEBUG_1("SIGBUS %p", info->si_addr);
@@ -1246,7 +1049,6 @@ static void setup_sigbus_handler(void)
 
 static void set_theme_bg_color()
 {
-#if GTK_CHECK_VERSION(3,0,0)
 	GdkRGBA bg_color;
 	GdkColor theme_color;
 	GtkStyleContext *style_context;
@@ -1274,10 +1076,9 @@ static void set_theme_bg_color()
 		}
 
 	view_window_colors_update();
-#endif
 }
 
-static gboolean theme_change_cb(GObject *gobject, GParamSpec *pspec, gpointer data)
+static gboolean theme_change_cb(GObject *UNUSED(gobject), GParamSpec *UNUSED(pspec), gpointer UNUSED(data))
 {
 	set_theme_bg_color();
 
@@ -1293,10 +1094,9 @@ static gboolean theme_change_cb(GObject *gobject, GParamSpec *pspec, gpointer da
  * They are now variables, all defined relative to one level above the
  * directory that the executable is run from.
  */
-static void create_application_paths(gchar *argv[])
+static void create_application_paths()
 {
 	gchar *dirname;
-	gchar *tmp;
 	gint length;
 	gchar *path;
 
@@ -1306,23 +1106,21 @@ static void create_application_paths(gchar *argv[])
 	path[length] = '\0';
 
 	gq_executable_path = g_strdup(path);
-	dirname = g_path_get_dirname(gq_executable_path); // default is /usr/bin/
+	dirname = g_path_get_dirname(gq_executable_path);
 	gq_prefix = g_path_get_dirname(dirname);
 
-	gq_localedir = g_build_filename(gq_prefix, "share", "locale", NULL);
-	tmp = g_build_filename(gq_prefix, "share", "doc", NULL);
-	gq_helpdir = g_strconcat(tmp, G_DIR_SEPARATOR_S, "geeqie-", VERSION, NULL);
-	gq_htmldir = g_build_filename(gq_helpdir, "html", NULL);
-	gq_app_dir = g_build_filename(gq_prefix, "share", "geeqie", NULL);
-	gq_bin_dir = g_build_filename(gq_prefix, "lib", "geeqie", NULL);
-	desktop_file_template = g_build_filename(gq_app_dir, "template.desktop", NULL);
+	gq_localedir = g_build_filename(gq_prefix, GQ_LOCALEDIR, NULL);
+	gq_helpdir = g_build_filename(gq_prefix, GQ_HELPDIR, NULL);
+	gq_htmldir = g_build_filename(gq_prefix, GQ_HTMLDIR, NULL);
+	gq_appdir = g_build_filename(gq_prefix, GQ_APPDIR, NULL);
+	gq_bindir = g_build_filename(gq_prefix, GQ_BINDIR, NULL);
+	desktop_file_template = g_build_filename(gq_appdir, "template.desktop", NULL);
 
-	g_free(tmp);
 	g_free(dirname);
 	g_free(path);
 }
 
-gboolean stderr_channel_cb(GIOChannel *source, GIOCondition condition, gpointer data)
+gboolean stderr_channel_cb(GIOChannel *source, GIOCondition UNUSED(condition), gpointer UNUSED(data))
 {
 	static GString *message_str = NULL;
 	gchar buf[10] = {0};
@@ -1367,19 +1165,15 @@ gint main(gint argc, gchar *argv[])
 	gint fd_stderr[2];
 	GIOChannel *stderr_channel;
 
-#ifdef HAVE_GTHREAD
-#if !GLIB_CHECK_VERSION(2,32,0)
-	g_thread_init(NULL);
-#endif
+	gdk_set_allowed_backends("x11,*");
+
 	gdk_threads_init();
 	gdk_threads_enter();
 
-#endif
-
 	/* init execution time counter (debug only) */
 	init_exec_time();
 
-	create_application_paths(argv);
+	create_application_paths();
 
 	/* setup locale, i18n */
 	setlocale(LC_ALL, "");
@@ -1673,9 +1467,8 @@ gint main(gint argc, gchar *argv[])
 
 	DEBUG_1("%s main: gtk_main", get_exec_time());
 	gtk_main();
-#ifdef HAVE_GTHREAD
+
 	gdk_threads_leave();
-#endif
 	return 0;
 }
 /* vim: set shiftwidth=8 softtabstop=0 cindent cinoptions={1s: */
