@@ -22,9 +22,7 @@
 #ifndef MAIN_H
 #define MAIN_H
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
+#include <config.h>
 
 #ifdef HAVE_STRVERSCMP
 #  ifndef _GNU_SOURCE
@@ -77,7 +75,7 @@
 
 #define GQ_APPNAME "Geeqie"
 #define GQ_APPNAME_LC "geeqie"
-#define GQ_WEBSITE "http://www.geeqie.org/"
+#define GQ_WEBSITE "https://www.geeqie.org/"
 #define GQ_EMAIL_ADDRESS "geeqie@freelists.org"
 
 #define GQ_RC_DIR		"." GQ_APPNAME_LC
@@ -135,6 +133,16 @@
 #define STAR_RATING_REJECTED 0x274C //Unicode Character 'Cross Mark'
 #define STAR_RATING_STAR 0x2738 //Unicode Character 'Heavy Eight Pointed Rectilinear Black Star'
 
+/* From http://stackoverflow.com/questions/3417837/ */
+#ifdef UNUSED
+#elif defined(__GNUC__)
+# define UNUSED(x) UNUSED_ ## x __attribute__((unused))
+#elif defined(__LCLINT__)
+# define UNUSED(x) /*@unused@*/ x
+#else
+# define UNUSED(x) x
+#endif
+
 /*
  *----------------------------------------------------------------------------
  * main.c
@@ -151,8 +159,8 @@ extern gchar *gq_prefix;
 extern gchar *gq_localedir;
 extern gchar *gq_helpdir;
 extern gchar *gq_htmldir;
-extern gchar *gq_app_dir;
-extern gchar *gq_bin_dir;
+extern gchar *gq_appdir;
+extern gchar *gq_bindir;
 extern gchar *gq_executable_path;
 extern gchar *desktop_file_template;
 extern gchar *instance_identifier;
