@@ -179,7 +179,7 @@ gchar *decode_geo_parameters(const gchar *input_text)
 	gchar *message;
 	gchar *dir;
 
-	message = decode_geo_script(gq_bin_dir, input_text);
+	message = decode_geo_script(gq_bindir, input_text);
 	if (strstr(message, "Error"))
 		{
 		g_free(message);
@@ -382,7 +382,7 @@ gint get_cpu_cores(void)
     return sysconf(_SC_NPROCESSORS_ONLN);
 }
 
-void tree_path_free_wrapper(void *data, void *useradata)
+void tree_path_free_wrapper(void *data, void *UNUSED(useradata))
 {
 	gtk_tree_path_free(data);
 }
@@ -390,7 +390,7 @@ void tree_path_free_wrapper(void *data, void *useradata)
 /* Copied from the libarchive .repo. examples */
 
 #ifndef HAVE_ARCHIVE
-gchar *open_archive(FileData *fd)
+gchar *open_archive(FileData *UNUSED(fd))
 {
 	log_printf("%s", _("Warning: libarchive not installed"));
 	return NULL;
