@@ -145,6 +145,7 @@ ConfOptions *init_options(ConfOptions *options)
 	options->image_l_click_video = FALSE;
 	options->image_l_click_video_editor = NULL;
 	options->open_recent_list_maxsize = 10;
+	options->recent_folder_image_list_maxsize = 10;
 	options->place_dialogs_under_mouse = FALSE;
 
 	options->progressive_key_scrolling = TRUE;
@@ -164,6 +165,7 @@ ConfOptions *init_options(ConfOptions *options)
 	options->metadata.keywords_case_sensitive = FALSE;
 	options->metadata.write_orientation = TRUE;
 	options->metadata.sidecar_extended_name = FALSE;
+	options->metadata.check_spelling = TRUE;
 
 	options->show_icon_names = TRUE;
 	options->show_star_rating = FALSE;
@@ -373,7 +375,7 @@ void save_options(ConfOptions *options)
 	g_free(rc_path);
 }
 
-gboolean load_options(ConfOptions *options)
+gboolean load_options(ConfOptions *UNUSED(options))
 {
 	gboolean success;
 	gchar *rc_path;
