@@ -58,6 +58,7 @@ struct _ConfOptions
 	gboolean sort_totals;
 
 	gint open_recent_list_maxsize;
+	gint recent_folder_image_list_maxsize;
 	gint dnd_icon_size;
 	DnDAction dnd_default_action;
 	gint clipboard_selection;
@@ -290,11 +291,13 @@ struct _ConfOptions
 		gboolean keywords_case_sensitive;
 		gboolean write_orientation;
 		gboolean sidecar_extended_name;
+
+		gboolean check_spelling;
 	} metadata;
 
 	/* Stereo */
 	struct {
-		gint mode;;
+		gint mode;
 		gint fsmode;
 		gboolean enable_fsmode;
 		gint fixed_w, fixed_h;
