@@ -46,6 +46,7 @@ gboolean pixbuf_scale_aspect(gint req_w, gint req_h, gint old_w, gint old_h, gin
 #define PIXBUF_INLINE_COLLECTION	"collection"
 #define PIXBUF_INLINE_ICON		"icon"
 #define PIXBUF_INLINE_LOGO		"logo"
+#define PIXBUF_INLINE_ARCHIVE		"archive"
 
 #define PIXBUF_INLINE_ICON_FLOAT	"icon_float"
 #define PIXBUF_INLINE_ICON_THUMB	"icon_thumb"
@@ -54,7 +55,6 @@ gboolean pixbuf_scale_aspect(gint req_w, gint req_h, gint old_w, gint old_h, gin
 #define PIXBUF_INLINE_ICON_CONFIG	"icon_config"
 #define PIXBUF_INLINE_ICON_TOOLS	"icon_tools"
 #define PIXBUF_INLINE_ICON_VIEW		"icon_view"
-#define PIXBUF_INLINE_ICON_GUIDELINES	"icon_guidelines"
 #define PIXBUF_INLINE_ICON_PANORAMA		"icon_panorama"
 #define PIXBUF_INLINE_ICON_MAINTENANCE	"icon_maintenance"
 #define PIXBUF_INLINE_ICON_ZOOMFILLHOR	"icon_zoomfillhor"
