@@ -30,6 +30,7 @@
 #include "bar_exif.h"
 #include "bar_histogram.h"
 #include "bar_keywords.h"
+#include "bar_rating.h"
 #include "bar_sort.h"
 #include "editors.h"
 #include "filefilter.h"
@@ -57,7 +58,7 @@ void write_indent(GString *str, gint indent)
 	g_string_append_printf(str, "\n%*s", indent * 4, "");
 }
 
-void write_char_option(GString *str, gint indent, const gchar *label, const gchar *text)
+void write_char_option(GString *str, gint UNUSED(indent), const gchar *label, const gchar *text)
 {
 	/* this is needed for overlay string, because g_markup_escape_text does not handle \n and such,
 	   ideas for improvement are welcome
@@ -133,7 +134,7 @@ gboolean read_color_option(const gchar *option, const gchar *label, const gchar
 	return TRUE;
 }
 
-void write_int_option(GString *str, gint indent, const gchar *label, gint n)
+void write_int_option(GString *str, gint UNUSED(indent), const gchar *label, gint n)
 {
 	g_string_append_printf(str, "%s = \"%d\" ", label, n);
 }
@@ -158,7 +159,7 @@ gboolean read_int_option(const gchar *option, const gchar *label, const gchar *v
 	return TRUE;
 }
 
-void write_ushort_option(GString *str, gint indent, const gchar *label, guint16 n)
+void write_ushort_option(GString *str, gint UNUSED(indent), const gchar *label, guint16 n)
 {
 	g_string_append_printf(str, "%s = \"%uh\" ", label, n);
 }
@@ -183,7 +184,7 @@ gboolean read_ushort_option(const gchar *option, const gchar *label, const gchar
 	return TRUE;
 }
 
-void write_uint_option(GString *str, gint indent, const gchar *label, guint n)
+void write_uint_option(GString *str, gint UNUSED(indent), const gchar *label, guint n)
 {
 	g_string_append_printf(str, "%s = \"%u\" ", label, n);
 }
@@ -229,7 +230,7 @@ gboolean read_int_option_clamp(const gchar *option, const gchar *label, const gc
 	return ret;
 }
 
-void write_int_unit_option(GString *str, gint indent, gchar *label, gint n, gint subunits)
+void write_int_unit_option(GString *str, gint UNUSED(indent), gchar *label, gint n, gint subunits)
 {
 	gint l, r;
 
@@ -278,7 +279,7 @@ gboolean read_int_unit_option(const gchar *option, const gchar *label, const gch
 	return TRUE;
 }
 
-void write_bool_option(GString *str, gint indent, gchar *label, gint n)
+void write_bool_option(GString *str, gint UNUSED(indent), gchar *label, gint n)
 {
 	g_string_append_printf(str, "%s = \"%s\" ", label, n ? "true" : "false");
 }
@@ -334,6 +335,7 @@ static void write_global_attributes(GString *outstr, gint indent)
 	WRITE_NL(); WRITE_BOOL(*options, image_l_click_video);
 	WRITE_NL(); WRITE_CHAR(*options, image_l_click_video_editor);
 	WRITE_NL(); WRITE_INT(*options, open_recent_list_maxsize);
+	WRITE_NL(); WRITE_INT(*options, recent_folder_image_list_maxsize);
 	WRITE_NL(); WRITE_INT(*options, dnd_icon_size);
 	WRITE_NL(); WRITE_UINT(*options, dnd_default_action);
 	WRITE_NL(); WRITE_BOOL(*options, place_dialogs_under_mouse);
@@ -400,7 +402,7 @@ static void write_global_attributes(GString *outstr, gint indent)
 	WRITE_NL(); WRITE_COLOR(*options, image.border_color);
 	WRITE_NL(); WRITE_COLOR(*options, image.alpha_color_1);
 	WRITE_NL(); WRITE_COLOR(*options, image.alpha_color_2);
-	WRITE_NL(); WRITE_BOOL(*options, image.use_clutter_renderer);
+	//~ WRITE_NL(); WRITE_BOOL(*options, image.use_clutter_renderer);
 	WRITE_NL(); WRITE_INT(*options, image.tile_size);
 
 	/* Thumbnails Options */
@@ -488,6 +490,7 @@ static void write_global_attributes(GString *outstr, gint indent)
 	WRITE_NL(); WRITE_BOOL(*options, metadata.confirm_on_dir_change);
 	WRITE_NL(); WRITE_BOOL(*options, metadata.keywords_case_sensitive);
 	WRITE_NL(); WRITE_BOOL(*options, metadata.write_orientation);
+	WRITE_NL(); WRITE_BOOL(*options, metadata.check_spelling);
 
 	WRITE_NL(); WRITE_INT(*options, stereo.mode);
 	WRITE_NL(); WRITE_INT(*options, stereo.fsmode);
@@ -542,7 +545,7 @@ static void write_color_profile(GString *outstr, gint indent)
 	gint i;
 #ifndef HAVE_LCMS
 	g_string_append_printf(outstr, "<!-- NOTICE: %s was not built with support for color profiles,\n"
-			    "         color profile options will have no effect.\n-->\n", GQ_APPNAME);
+				"		 color profile options will have no effect.\n-->\n", GQ_APPNAME);
 #endif
 
 	WRITE_NL(); WRITE_STRING("<color_profiles ");
@@ -658,12 +661,12 @@ gboolean save_config_to_file(const gchar *utf8_path, ConfOptions *options, Layou
 	outstr = g_string_new("");
 	g_string_append_printf(outstr, "<!--\n");
 	g_string_append_printf(outstr, "######################################################################\n");
-	g_string_append_printf(outstr, "# %30s config file      version %-10s #\n", GQ_APPNAME, VERSION);
+	g_string_append_printf(outstr, "# %30s config file	  version %-10s #\n", GQ_APPNAME, VERSION);
 	g_string_append_printf(outstr, "######################################################################\n");
 	WRITE_SEPARATOR();
 
 	WRITE_STRING("# Note: This file is autogenerated. Options can be changed here,\n");
-	WRITE_STRING("#       but user comments and formatting will be lost.\n");
+	WRITE_STRING("#	   but user comments and formatting will be lost.\n");
 	WRITE_SEPARATOR();
 	WRITE_STRING("-->\n");
 	WRITE_SEPARATOR();
@@ -739,7 +742,7 @@ gboolean save_config_to_file(const gchar *utf8_path, ConfOptions *options, Layou
 	return TRUE;
 }
 
-gboolean save_default_layout_options_to_file(const gchar *utf8_path, ConfOptions *options, LayoutWindow *lw)
+gboolean save_default_layout_options_to_file(const gchar *utf8_path, ConfOptions *UNUSED(options), LayoutWindow *lw)
 {
 	SecureSaveInfo *ssi;
 	gchar *rc_pathl;
@@ -758,12 +761,12 @@ gboolean save_default_layout_options_to_file(const gchar *utf8_path, ConfOptions
 	outstr = g_string_new("");
 	g_string_append_printf(outstr, "<!--\n");
 	g_string_append_printf(outstr, "######################################################################\n");
-	g_string_append_printf(outstr, "# %8s default layout file      version %-10s #\n", GQ_APPNAME, VERSION);
+	g_string_append_printf(outstr, "# %8s default layout file	  version %-10s #\n", GQ_APPNAME, VERSION);
 	g_string_append_printf(outstr, "######################################################################\n");
 	WRITE_SEPARATOR();
 
 	WRITE_STRING("# Note: This file is autogenerated. Options can be changed here,\n");
-	WRITE_STRING("#       but user comments and formatting will be lost.\n");
+	WRITE_STRING("#	   but user comments and formatting will be lost.\n");
 	WRITE_SEPARATOR();
 	WRITE_STRING("-->\n");
 	WRITE_SEPARATOR();
@@ -832,8 +835,9 @@ static gboolean load_global_params(const gchar **attribute_names, const gchar **
 		if (READ_CHAR(*options, image_l_click_video_editor)) continue;
 
 		if (READ_INT(*options, open_recent_list_maxsize)) continue;
+		if (READ_INT(*options, recent_folder_image_list_maxsize)) continue;
 		if (READ_INT(*options, dnd_icon_size)) continue;
-		if (READ_UINT(*options, dnd_default_action)) continue;
+		if (READ_UINT_ENUM(*options, dnd_default_action)) continue;
 		if (READ_BOOL(*options, place_dialogs_under_mouse)) continue;
 		if (READ_INT(*options, clipboard_selection)) continue;
 
@@ -864,8 +868,8 @@ static gboolean load_global_params(const gchar **attribute_names, const gchar **
 		if (READ_BOOL(*options, with_rename)) continue;
 
 		/* Image options */
-		if (READ_UINT_CLAMP(*options, image.zoom_mode, 0, ZOOM_RESET_NONE)) continue;
-		if (READ_UINT_CLAMP(*options, image.zoom_style, 0, ZOOM_ARITHMETIC)) continue;
+		if (READ_UINT_ENUM_CLAMP(*options, image.zoom_mode, 0, ZOOM_RESET_NONE)) continue;
+		if (READ_UINT_ENUM_CLAMP(*options, image.zoom_style, 0, ZOOM_ARITHMETIC)) continue;
 		if (READ_BOOL(*options, image.zoom_2pass)) continue;
 		if (READ_BOOL(*options, image.zoom_to_fit_allow_expand)) continue;
 		if (READ_BOOL(*options, image.fit_window_to_image)) continue;
@@ -886,7 +890,7 @@ static gboolean load_global_params(const gchar **attribute_names, const gchar **
 		if (READ_COLOR(*options, image.border_color)) continue;
 		if (READ_COLOR(*options, image.alpha_color_1)) continue;
 		if (READ_COLOR(*options, image.alpha_color_2)) continue;
-		if (READ_BOOL(*options, image.use_clutter_renderer)) continue;
+		//~ if (READ_BOOL(*options, image.use_clutter_renderer)) continue;
 		if (READ_INT(*options, image.tile_size)) continue;
 
 		/* Thumbnails options */
@@ -905,7 +909,7 @@ static gboolean load_global_params(const gchar **attribute_names, const gchar **
 // 		if (READ_BOOL(*options, thumbnails.use_ft_metadata_small)) continue;
 
 		/* File sorting options */
-		if (READ_UINT(*options, file_sort.method)) continue;
+		if (READ_UINT_ENUM(*options, file_sort.method)) continue;
 		if (READ_BOOL(*options, file_sort.ascending)) continue;
 		if (READ_BOOL(*options, file_sort.case_sensitive)) continue;
 		if (READ_BOOL(*options, file_sort.natural)) continue;
@@ -982,6 +986,7 @@ static gboolean load_global_params(const gchar **attribute_names, const gchar **
 		if (READ_BOOL(*options, metadata.confirm_on_dir_change)) continue;
 		if (READ_BOOL(*options, metadata.keywords_case_sensitive)) continue;
 		if (READ_BOOL(*options, metadata.write_orientation)) continue;
+		if (READ_BOOL(*options, metadata.check_spelling)) continue;
 
 		if (READ_INT(*options, stereo.mode)) continue;
 		if (READ_INT(*options, stereo.fsmode)) continue;
@@ -1034,7 +1039,7 @@ static gboolean load_global_params(const gchar **attribute_names, const gchar **
 	return TRUE;
 }
 
-static void options_load_color_profiles(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **error)
+static void options_load_color_profiles(GQParserData *UNUSED(parser_data), GMarkupParseContext *UNUSED(context), const gchar *UNUSED(element_name), const gchar **attribute_names, const gchar **attribute_values, gpointer UNUSED(data), GError **UNUSED(error))
 {
 	while (*attribute_names)
 		{
@@ -1053,7 +1058,7 @@ static void options_load_color_profiles(GQParserData *parser_data, GMarkupParseC
 
 }
 
-static void options_load_profile(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **error)
+static void options_load_profile(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *UNUSED(element_name), const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **UNUSED(error))
 {
 	gint i = GPOINTER_TO_INT(data);
 	if (i < 0 || i >= COLOR_PROFILE_INPUTS) return;
@@ -1072,7 +1077,7 @@ static void options_load_profile(GQParserData *parser_data, GMarkupParseContext
 
 }
 
-static void options_load_marks_tooltips(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **error)
+static void options_load_marks_tooltips(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *UNUSED(element_name), const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **UNUSED(error))
 {
 	gint i = GPOINTER_TO_INT(data);
 	if (i < 0 || i >= FILEDATA_MARKS_SIZE) return;
@@ -1089,7 +1094,7 @@ static void options_load_marks_tooltips(GQParserData *parser_data, GMarkupParseC
 
 }
 
-static void options_load_disabled_plugins(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **error)
+static void options_load_disabled_plugins(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *UNUSED(element_name), const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **UNUSED(error))
 {
 	gint i = GPOINTER_TO_INT(data);
 	struct {
@@ -1138,7 +1143,7 @@ static const gchar *options_get_id(const gchar **attribute_names, const gchar **
 }
 
 
-void options_parse_leaf(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **error)
+void options_parse_leaf(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **UNUSED(attribute_names), const gchar **UNUSED(attribute_values), gpointer UNUSED(data), GError **UNUSED(error))
 {
 	log_printf("unexpected: %s\n", element_name);
 	options_parse_func_push(parser_data, options_parse_leaf, NULL, NULL);
@@ -1174,34 +1179,67 @@ static void options_parse_marks_tooltips(GQParserData *parser_data, GMarkupParse
 
 static void class_filter_load_filter_type(const gchar **attribute_names, const gchar **attribute_values)
 {
-	gint i;
-	gint index;
+	// This is called with all attributes for a given XML element.  So for
+	// a sample input of:
+	// <filter_type filter = "RAW Image" enabled = "true" />
+	// attribute_names will be {"filter", "enabled"} and attribute_values
+	// will be {"RAW Image", "true"}.
+	// For a sample input of:
+	// <filter_type enabled = "true" filter = "RAW Image" />
+	// attribute_names will be {"enabled", "filter"} and attribute_values
+	// will be {"true", "RAW Image"}.
 
+	const gchar *enabled_name = NULL;
+	const gchar *enabled_value = NULL;
+	int format_class_index = -1;
+
+	// In this loop, we iterate through matching attribute/value pairs in
+	// tandem, looking for a "filter" value and an "enabled" value.
 	while (*attribute_names)
 		{
 		const gchar *option = *attribute_names++;
 		const gchar *value = *attribute_values++;
+
+		// If the name is "filter" and the value is in our
+		// format_class_list, then stash the format class index.
 		if (g_strcmp0("filter", option) == 0)
 			{
-			for (i = 0; i < FILE_FORMAT_CLASSES; i++)
+			for (int i = 0; i < FILE_FORMAT_CLASSES; i++)
 				{
 				if (g_strcmp0(format_class_list[i], value) == 0)
 					{
-					index = i;
+					format_class_index = i;
+					break;
 					}
 				}
 			continue;
 			}
 
-		if (READ_BOOL_FULL("enabled", options->class_filter[index]))
+		if (g_strcmp0("enabled", option) == 0)
 			{
+			enabled_name = option;
+			enabled_value = value;
 			continue;
 			}
+
 		log_printf("unknown attribute %s = %s\n", option, value);
 		}
+
+	if (enabled_name == NULL || enabled_value == NULL || format_class_index < 0)
+		{
+		log_printf("Failed to parse <filter_type> config element\n");
+		return;
+		}
+
+	if (!read_bool_option(enabled_name, "enabled", enabled_value,
+						  &(options->class_filter[format_class_index])))
+		{
+		log_printf("Failed to load <filter_type> config element with "
+			   "class index %d\n", format_class_index);
+		}
 }
 
-static void options_parse_class_filter(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **error)
+static void options_parse_class_filter(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer UNUSED(data), GError **UNUSED(error))
 {
 	if (g_ascii_strcasecmp(element_name, "filter_type") == 0)
 		{
@@ -1229,7 +1267,7 @@ static void options_parse_disabled_plugins(GQParserData *parser_data, GMarkupPar
 		}
 }
 
-static void options_parse_filter(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **error)
+static void options_parse_filter(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer UNUSED(data), GError **UNUSED(error))
 {
 	if (g_ascii_strcasecmp(element_name, "file_type") == 0)
 		{
@@ -1243,20 +1281,20 @@ static void options_parse_filter(GQParserData *parser_data, GMarkupParseContext
 		}
 }
 
-static void options_parse_filter_end(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, gpointer data, GError **error)
+static void options_parse_filter_end(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *UNUSED(element_name), gpointer UNUSED(data), GError **UNUSED(error))
 {
 	if (parser_data->startup) filter_add_defaults();
 	filter_rebuild();
 }
 
-static void options_parse_keyword_end(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, gpointer data, GError **error)
+static void options_parse_keyword_end(GQParserData *UNUSED(parser_data), GMarkupParseContext *UNUSED(context), const gchar *UNUSED(element_name), gpointer data, GError **UNUSED(error))
 {
 	GtkTreeIter *iter_ptr = data;
 	gtk_tree_iter_free(iter_ptr);
 }
 
 
-static void options_parse_keyword(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **error)
+static void options_parse_keyword(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **UNUSED(error))
 {
 	GtkTreeIter *iter_ptr = data;
 	if (g_ascii_strcasecmp(element_name, "keyword") == 0)
@@ -1273,7 +1311,7 @@ static void options_parse_keyword(GQParserData *parser_data, GMarkupParseContext
 
 
 
-static void options_parse_keyword_tree(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **error)
+static void options_parse_keyword_tree(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer UNUSED(data), GError **UNUSED(error))
 {
 	if (g_ascii_strcasecmp(element_name, "keyword") == 0)
 		{
@@ -1325,7 +1363,7 @@ static void options_parse_global(GQParserData *parser_data, GMarkupParseContext
 		}
 }
 
-static void options_parse_global_end(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, gpointer data, GError **error)
+static void options_parse_global_end(GQParserData *UNUSED(parser_data), GMarkupParseContext *UNUSED(context), const gchar *UNUSED(element_name), gpointer UNUSED(data), GError **UNUSED(error))
 {
 #ifndef HAVE_EXIV2
 	/* some options do not work without exiv2 */
@@ -1336,7 +1374,7 @@ static void options_parse_global_end(GQParserData *parser_data, GMarkupParseCont
 #endif
 }
 
-static void options_parse_pane_exif(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **error)
+static void options_parse_pane_exif(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **UNUSED(error))
 {
 	GtkWidget *pane = data;
 	if (g_ascii_strcasecmp(element_name, "entry") == 0)
@@ -1351,7 +1389,7 @@ static void options_parse_pane_exif(GQParserData *parser_data, GMarkupParseConte
 		}
 }
 
-static void options_parse_pane_keywords(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **error)
+static void options_parse_pane_keywords(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **UNUSED(error))
 {
 	GtkWidget *pane = data;
 
@@ -1367,7 +1405,7 @@ static void options_parse_pane_keywords(GQParserData *parser_data, GMarkupParseC
 		}
 }
 
-static void options_parse_bar(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **error)
+static void options_parse_bar(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **UNUSED(error))
 {
 	GtkWidget *bar = data;
 	if (g_ascii_strcasecmp(element_name, "pane_comment") == 0)
@@ -1434,6 +1472,20 @@ static void options_parse_bar(GQParserData *parser_data, GMarkupParseContext *co
 			}
 		options_parse_func_push(parser_data, options_parse_leaf, NULL, NULL);
 		}
+	else if (g_ascii_strcasecmp(element_name, "pane_rating") == 0)
+		{
+		GtkWidget *pane = bar_find_pane_by_id(bar, PANE_RATING, options_get_id(attribute_names, attribute_values));
+		if (pane)
+			{
+			bar_pane_rating_update_from_config(pane, attribute_names, attribute_values);
+			}
+		else
+			{
+			pane = bar_pane_rating_new_from_config(attribute_names, attribute_values);
+			bar_add(bar, pane);
+			}
+		options_parse_func_push(parser_data, options_parse_leaf, NULL, NULL);
+		}
 	else if (g_ascii_strcasecmp(element_name, "pane_keywords") == 0)
 		{
 		GtkWidget *pane = bar_find_pane_by_id(bar, PANE_KEYWORDS, options_get_id(attribute_names, attribute_values));
@@ -1460,7 +1512,7 @@ static void options_parse_bar(GQParserData *parser_data, GMarkupParseContext *co
 		}
 }
 
-static void options_parse_toolbar(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **error)
+static void options_parse_toolbar(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **UNUSED(error))
 {
 	LayoutWindow *lw = data;
 	if (g_ascii_strcasecmp(element_name, "toolitem") == 0)
@@ -1480,7 +1532,7 @@ static void options_parse_toolbar(GQParserData *parser_data, GMarkupParseContext
 		}
 }
 
-static void options_parse_statusbar(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **error)
+static void options_parse_statusbar(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **UNUSED(error))
 {
 	LayoutWindow *lw = data;
 	if (g_ascii_strcasecmp(element_name, "toolitem") == 0)
@@ -1500,7 +1552,7 @@ static void options_parse_statusbar(GQParserData *parser_data, GMarkupParseConte
 		}
 }
 
-static void options_parse_dialogs(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **error)
+static void options_parse_dialogs(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer UNUSED(data), GError **UNUSED(error))
 {
 	if (g_ascii_strcasecmp(element_name, "window") == 0)
 		{
@@ -1514,7 +1566,7 @@ static void options_parse_dialogs(GQParserData *parser_data, GMarkupParseContext
 		}
 }
 
-static void options_parse_layout(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **error)
+static void options_parse_layout(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **UNUSED(error))
 {
 	LayoutWindow *lw = data;
 	if (g_ascii_strcasecmp(element_name, "bar") == 0)
@@ -1555,13 +1607,13 @@ static void options_parse_layout(GQParserData *parser_data, GMarkupParseContext
 		}
 }
 
-static void options_parse_layout_end(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, gpointer data, GError **error)
+static void options_parse_layout_end(GQParserData *UNUSED(parser_data), GMarkupParseContext *UNUSED(context), const gchar *UNUSED(element_name), gpointer data, GError **UNUSED(error))
 {
 	LayoutWindow *lw = data;
 	layout_util_sync(lw);
 }
 
-static void options_parse_toplevel(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **error)
+static void options_parse_toplevel(GQParserData *parser_data, GMarkupParseContext *UNUSED(context), const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer UNUSED(data), GError **UNUSED(error))
 {
 	if (g_ascii_strcasecmp(element_name, "gq") == 0)
 		{
