@@ -304,6 +304,8 @@ static gboolean slideshow_step(SlideShowData *ss, gboolean forward)
 	return TRUE;
 }
 
+static void slideshow_timer_reset(SlideShowData *ss);
+
 static gboolean slideshow_loop_cb(gpointer data)
 {
 	SlideShowData *ss = data;
@@ -317,6 +319,9 @@ static gboolean slideshow_loop_cb(gpointer data)
 		return FALSE;
 		}
 
+	/* Check if the user has changed the timer interval */
+	slideshow_timer_reset(ss);
+
 	return TRUE;
 }
 
@@ -373,7 +378,7 @@ static SlideShowData *real_slideshow_start(LayoutWindow *target_lw, ImageWindow
 	ss = g_new0(SlideShowData, 1);
 
 	ss->lw = target_lw;
-	ss->imd = imd; /* FIXME: ss->imd is used only for img-view.c and can be dropped with it */
+	ss->imd = imd; /** @FIXME ss->imd is used only for img-view.c and can be dropped with it */
 	ss->filelist = filelist;
 	ss->cd = cd;
 
