@@ -19,9 +19,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
+#include <config.h>
 
 #include <pwd.h>
 #include <stdio.h>
@@ -733,7 +731,7 @@ gchar *get_current_dir(void)
 	return path8;
 }
 
-void list_free_wrapper(void *data, void *userdata)
+void list_free_wrapper(void *data, void *UNUSED(userdata))
 {
 	g_free(data);
 }
@@ -1065,7 +1063,7 @@ static void web_file_progress_cb(goffset current_num_bytes, goffset total_num_by
 		}
 }
 
-static void download_web_file_cancel_button_cb(GenericDialog *gd, gpointer data)
+static void download_web_file_cancel_button_cb(GenericDialog *UNUSED(gd), gpointer data)
 {
 	WebData* web = data;
 
@@ -1080,7 +1078,7 @@ gboolean download_web_file(const gchar *text, gboolean minimized, gpointer data)
 	GError *error = NULL;
 	WebData *web;
 	gchar *base;
-	gboolean ret;
+	gboolean ret = FALSE;
 	gchar *message;
 	FileFormatClass format_class;
 
@@ -1163,4 +1161,18 @@ gboolean rmdir_recursive(GFile *file, GCancellable *cancellable, GError **error)
 	return g_file_delete(file, cancellable, error);
 }
 
+/**
+ * @brief Retrieves the internal scale factor that maps from window coordinates to the actual device pixels
+ * @param  -
+ * @returns scale factor
+ * 
+ * 
+ */
+gint scale_factor()
+{
+	LayoutWindow *lw = NULL;
+
+	layout_valid(&lw);
+	return gtk_widget_get_scale_factor(lw->window);
+}
 /* vim: set shiftwidth=8 softtabstop=0 cindent cinoptions={1s: */
