@@ -19,9 +19,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
+#include <config.h>
 #include "intl.h"
 
 #include <stdio.h>
@@ -102,7 +100,7 @@ static void spinner_set_timeout(SpinnerData *sp, gint interval)
 	gtk_widget_set_sensitive(sp->image, (interval >= 0));
 }
 
-static void spinner_destroy_cb(GtkWidget *widget, gpointer data)
+static void spinner_destroy_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	SpinnerData *sp = data;
 	GList *work;
