@@ -19,9 +19,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
+#include <config.h>
 #include "intl.h"
 
 #include <stdio.h>
@@ -33,6 +31,7 @@
 
 #include "compat.h"
 
+#include "main.h"
 #include "ui_tree_edit.h"
 
 /*
@@ -72,7 +71,7 @@ static void tree_edit_do(TreeEditData *ted)
 		}
 }
 
-static gboolean tree_edit_click_end_cb(GtkWidget *widget, GdkEventButton *event, gpointer data)
+static gboolean tree_edit_click_end_cb(GtkWidget *UNUSED(widget), GdkEventButton *UNUSED(event), gpointer data)
 {
 	TreeEditData *ted = data;
 
@@ -82,7 +81,7 @@ static gboolean tree_edit_click_end_cb(GtkWidget *widget, GdkEventButton *event,
 	return TRUE;
 }
 
-static gboolean tree_edit_click_cb(GtkWidget *widget, GdkEventButton *event, gpointer data)
+static gboolean tree_edit_click_cb(GtkWidget *UNUSED(widget), GdkEventButton *event, gpointer data)
 {
 	TreeEditData *ted = data;
 	GdkWindow *window = gtk_widget_get_window(ted->window);
@@ -109,7 +108,7 @@ static gboolean tree_edit_click_cb(GtkWidget *widget, GdkEventButton *event, gpo
 	return FALSE;
 }
 
-static gboolean tree_edit_key_press_cb(GtkWidget *widget, GdkEventKey *event, gpointer data)
+static gboolean tree_edit_key_press_cb(GtkWidget *UNUSED(widget), GdkEventKey *event, gpointer data)
 {
 	TreeEditData *ted = data;
 
@@ -284,11 +283,7 @@ gboolean tree_view_get_cell_origin(GtkTreeView *widget, GtkTreePath *tpath, gint
 	if (gtk_tree_view_get_headers_visible(widget))
 		{
 		GtkAllocation allocation;
-#if GTK_CHECK_VERSION(3,0,0)
 		gtk_widget_get_allocation(gtk_tree_view_column_get_button(tv_column), &allocation);
-#else
-		gtk_widget_get_allocation(tv_column->button, &allocation);
-#endif
 		header_size = allocation.height;
 		}
 	else
@@ -575,10 +570,8 @@ static gboolean widget_auto_scroll_cb(gpointer data)
 	gint x, y;
 	gint w, h;
 	gint amt = 0;
-#if GTK_CHECK_VERSION(3,0,0)
 	GdkDeviceManager *device_manager;
 	GdkDevice *device;
-#endif
 
 	if (sd->max_step < sd->region_size)
 		{
@@ -586,13 +579,10 @@ static gboolean widget_auto_scroll_cb(gpointer data)
 		}
 
 	window = gtk_widget_get_window(sd->widget);
-#if GTK_CHECK_VERSION(3,0,0)
 	device_manager = gdk_display_get_device_manager(gdk_window_get_display(window));
 	device = gdk_device_manager_get_client_pointer(device_manager);
 	gdk_window_get_device_position(window, device, &x, &y, NULL);
-#else
-	gdk_window_get_pointer(window, &x, &y, NULL);
-#endif
+
 	w = gdk_window_get_width(window);
 	h = gdk_window_get_height(window);
 
