@@ -151,6 +151,12 @@ static gboolean vdlist_populate(ViewDir *vd, gboolean clear)
 	gboolean sort_ascend = TRUE;
 	gchar *link = NULL;
 
+	if (vd->layout)
+		{
+		sort_type = vd->layout->options.dir_view_list_sort.method;
+		sort_ascend = vd->layout->options.dir_view_list_sort.ascend;
+		}
+
 	old_list = VDLIST(vd)->list;
 
 	ret = filelist_read(vd->dir_fd, NULL, &VDLIST(vd)->list);
@@ -429,7 +435,7 @@ gboolean vdlist_press_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer dat
 	return options->view_dir_list_single_click_enter;
 }
 
-void vdlist_destroy_cb(GtkWidget *widget, gpointer data)
+void vdlist_destroy_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewDir *vd = data;
 
@@ -439,7 +445,7 @@ void vdlist_destroy_cb(GtkWidget *widget, gpointer data)
 	filelist_free(VDLIST(vd)->list);
 }
 
-ViewDir *vdlist_new(ViewDir *vd, FileData *dir_fd)
+ViewDir *vdlist_new(ViewDir *vd, FileData *UNUSED(dir_fd))
 {
 	GtkListStore *store;
 	GtkTreeSelection *selection;
