@@ -367,7 +367,7 @@ static void vf_pop_menu_view_cb(GtkWidget *widget, gpointer data)
 	}
 }
 
-static void vf_pop_menu_open_archive_cb(GtkWidget *widget, gpointer data)
+static void vf_pop_menu_open_archive_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 	LayoutWindow *lw_new;
@@ -397,14 +397,14 @@ static void vf_pop_menu_open_archive_cb(GtkWidget *widget, gpointer data)
 		}
 }
 
-static void vf_pop_menu_copy_cb(GtkWidget *widget, gpointer data)
+static void vf_pop_menu_copy_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 
 	file_util_copy(NULL, vf_pop_menu_file_list(vf), NULL, vf->listview);
 }
 
-static void vf_pop_menu_move_cb(GtkWidget *widget, gpointer data)
+static void vf_pop_menu_move_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 
@@ -422,7 +422,7 @@ static void vf_pop_menu_rename_cb(GtkWidget *widget, gpointer data)
 	}
 }
 
-static void vf_pop_menu_delete_cb(GtkWidget *widget, gpointer data)
+static void vf_pop_menu_delete_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 
@@ -430,7 +430,7 @@ static void vf_pop_menu_delete_cb(GtkWidget *widget, gpointer data)
 	file_util_delete(NULL, vf_pop_menu_file_list(vf), vf->listview);
 }
 
-static void vf_pop_menu_move_to_trash_cb(GtkWidget *widget, gpointer data)
+static void vf_pop_menu_move_to_trash_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 
@@ -438,28 +438,28 @@ static void vf_pop_menu_move_to_trash_cb(GtkWidget *widget, gpointer data)
 	file_util_delete(NULL, vf_pop_menu_file_list(vf), vf->listview);
 }
 
-static void vf_pop_menu_copy_path_cb(GtkWidget *widget, gpointer data)
+static void vf_pop_menu_copy_path_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 
 	file_util_copy_path_list_to_clipboard(vf_pop_menu_file_list(vf), TRUE);
 }
 
-static void vf_pop_menu_copy_path_unquoted_cb(GtkWidget *widget, gpointer data)
+static void vf_pop_menu_copy_path_unquoted_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 
 	file_util_copy_path_list_to_clipboard(vf_pop_menu_file_list(vf), FALSE);
 }
 
-static void vf_pop_menu_enable_grouping_cb(GtkWidget *widget, gpointer data)
+static void vf_pop_menu_enable_grouping_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 
 	file_data_disable_grouping_list(vf_pop_menu_file_list(vf), FALSE);
 }
 
-static void vf_pop_menu_duplicates_cb(GtkWidget *widget, gpointer data)
+static void vf_pop_menu_duplicates_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 	DupeWindow *dw;
@@ -468,7 +468,7 @@ static void vf_pop_menu_duplicates_cb(GtkWidget *widget, gpointer data)
 	dupe_window_add_files(dw, vf_pop_menu_file_list(vf), FALSE);
 }
 
-static void vf_pop_menu_disable_grouping_cb(GtkWidget *widget, gpointer data)
+static void vf_pop_menu_disable_grouping_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 
@@ -502,7 +502,7 @@ static void vf_pop_menu_sort_cb(GtkWidget *widget, gpointer data)
 		}
 }
 
-static void vf_pop_menu_sort_ascend_cb(GtkWidget *widget, gpointer data)
+static void vf_pop_menu_sort_ascend_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 
@@ -516,43 +516,43 @@ static void vf_pop_menu_sort_ascend_cb(GtkWidget *widget, gpointer data)
 		}
 }
 
-static void vf_pop_menu_sel_mark_cb(GtkWidget *widget, gpointer data)
+static void vf_pop_menu_sel_mark_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 	vf_mark_to_selection(vf, vf->active_mark, MTS_MODE_SET);
 }
 
-static void vf_pop_menu_sel_mark_and_cb(GtkWidget *widget, gpointer data)
+static void vf_pop_menu_sel_mark_and_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 	vf_mark_to_selection(vf, vf->active_mark, MTS_MODE_AND);
 }
 
-static void vf_pop_menu_sel_mark_or_cb(GtkWidget *widget, gpointer data)
+static void vf_pop_menu_sel_mark_or_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 	vf_mark_to_selection(vf, vf->active_mark, MTS_MODE_OR);
 }
 
-static void vf_pop_menu_sel_mark_minus_cb(GtkWidget *widget, gpointer data)
+static void vf_pop_menu_sel_mark_minus_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 	vf_mark_to_selection(vf, vf->active_mark, MTS_MODE_MINUS);
 }
 
-static void vf_pop_menu_set_mark_sel_cb(GtkWidget *widget, gpointer data)
+static void vf_pop_menu_set_mark_sel_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 	vf_selection_to_mark(vf, vf->active_mark, STM_MODE_SET);
 }
 
-static void vf_pop_menu_res_mark_sel_cb(GtkWidget *widget, gpointer data)
+static void vf_pop_menu_res_mark_sel_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 	vf_selection_to_mark(vf, vf->active_mark, STM_MODE_RESET);
 }
 
-static void vf_pop_menu_toggle_mark_sel_cb(GtkWidget *widget, gpointer data)
+static void vf_pop_menu_toggle_mark_sel_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 	vf_selection_to_mark(vf, vf->active_mark, STM_MODE_TOGGLE);
@@ -835,7 +835,7 @@ static void vf_destroy_cb(GtkWidget *widget, gpointer data)
 	g_free(vf);
 }
 
-static void vf_marks_filter_toggle_cb(GtkWidget *widget, gpointer data)
+static void vf_marks_filter_toggle_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 	vf_refresh_idle(vf);
@@ -871,8 +871,8 @@ static void vf_marks_tooltip_ok_cb(GenericDialog *gd, gpointer data)
 	generic_dialog_close(gd);
 }
 
-void vf_marks_filter_on_icon_press(GtkEntry *entry, GtkEntryIconPosition pos,
-									GdkEvent *event, gpointer userdata)
+void vf_marks_filter_on_icon_press(GtkEntry *UNUSED(entry), GtkEntryIconPosition UNUSED(pos),
+									GdkEvent *UNUSED(event), gpointer userdata)
 {
 	MarksTextEntry *mte = userdata;
 
@@ -881,7 +881,7 @@ void vf_marks_filter_on_icon_press(GtkEntry *entry, GtkEntryIconPosition pos,
 	gtk_entry_set_text(GTK_ENTRY(mte->edit_widget), "");
 }
 
-static void vf_marks_tooltip_help_cb(GenericDialog *gd, gpointer data)
+static void vf_marks_tooltip_help_cb(GenericDialog *UNUSED(gd), gpointer UNUSED(data))
 {
 	help_window_show("GuideImageMarks.html");
 }
@@ -939,7 +939,7 @@ static gboolean vf_marks_tooltip_cb(GtkWidget *widget,
 	return FALSE;
 }
 
-static void vf_file_filter_save_cb(GtkWidget *widget, gpointer data)
+static void vf_file_filter_save_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 	gchar *entry_text;
@@ -998,14 +998,14 @@ static void vf_file_filter_save_cb(GtkWidget *widget, gpointer data)
 	g_free(entry_text);
 }
 
-static void vf_file_filter_cb(GtkWidget *widget, gpointer data)
+static void vf_file_filter_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 
 	vf_refresh(vf);
 }
 
-static gboolean vf_file_filter_press_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer data)
+static gboolean vf_file_filter_press_cb(GtkWidget *widget, GdkEventButton *UNUSED(bevent), gpointer data)
 {
 	ViewFile *vf = data;
 	vf->file_filter.last_selected = gtk_combo_box_get_active(GTK_COMBO_BOX(vf->file_filter.combo));
@@ -1018,7 +1018,7 @@ static gboolean vf_file_filter_press_cb(GtkWidget *widget, GdkEventButton *beven
 static GtkWidget *vf_marks_filter_init(ViewFile *vf)
 {
 	GtkWidget *frame = gtk_frame_new(NULL);
-	GtkWidget *hbox = gtk_hbox_new(FALSE, 0);
+	GtkWidget *hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 
 	gint i;
 
@@ -1155,22 +1155,38 @@ static void case_sensitive_cb(GtkWidget *widget, gpointer data)
 	vf_refresh(vf);
 }
 
+static void file_filter_clear_cb(GtkEntry *UNUSED(entry), GtkEntryIconPosition pos, GdkEvent *UNUSED(event), gpointer userdata)
+{
+	if (pos == GTK_ENTRY_ICON_SECONDARY)
+		{
+		gtk_entry_set_text(GTK_ENTRY(userdata), "");
+		gtk_widget_grab_focus(GTK_WIDGET(userdata));
+		}
+}
+
 static GtkWidget *vf_file_filter_init(ViewFile *vf)
 {
 	GtkWidget *frame = gtk_frame_new(NULL);
-	GtkWidget *hbox = gtk_hbox_new(FALSE, 0);
+	GtkWidget *hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	GList *work;
 	gint n = 0;
 	GtkWidget *combo_entry;
 	GtkWidget *menubar;
 	GtkWidget *menuitem;
 	GtkWidget *case_sensitive;
+	GtkWidget *box;
+	GtkWidget *icon;
+	GtkWidget *label;
 
 	vf->file_filter.combo = gtk_combo_box_text_new_with_entry();
 	combo_entry = gtk_bin_get_child(GTK_BIN(vf->file_filter.combo));
 	gtk_widget_show(gtk_bin_get_child(GTK_BIN(vf->file_filter.combo)));
 	gtk_widget_show((GTK_WIDGET(vf->file_filter.combo)));
-	gtk_widget_set_tooltip_text(GTK_WIDGET(vf->file_filter.combo), "Use regular expressions");
+	gtk_widget_set_tooltip_text(GTK_WIDGET(vf->file_filter.combo), _("Use regular expressions"));
+
+	gtk_entry_set_icon_from_stock(GTK_ENTRY(combo_entry), GTK_ENTRY_ICON_SECONDARY, GTK_STOCK_CLEAR);
+	gtk_entry_set_icon_tooltip_text (GTK_ENTRY(combo_entry), GTK_ENTRY_ICON_SECONDARY, _("Clear"));
+	g_signal_connect(GTK_ENTRY(combo_entry), "icon-press", G_CALLBACK(file_filter_clear_cb), combo_entry);
 
 	work = history_list_get_by_key("file_filter");
 	while (work)
@@ -1196,7 +1212,7 @@ static GtkWidget *vf_file_filter_init(ViewFile *vf)
 	gtk_container_add(GTK_CONTAINER(frame), hbox);
 	gtk_widget_show(hbox);
 
-	case_sensitive = gtk_check_button_new_with_label("Case");
+	case_sensitive = gtk_check_button_new_with_label(_("Case"));
 	gtk_box_pack_start(GTK_BOX(hbox), case_sensitive, FALSE, FALSE, 0);
 	gtk_widget_set_tooltip_text(GTK_WIDGET(case_sensitive), _("Case sensitive"));
 	g_signal_connect(G_OBJECT(case_sensitive), "clicked", G_CALLBACK(case_sensitive_cb), vf);
@@ -1206,13 +1222,20 @@ static GtkWidget *vf_file_filter_init(ViewFile *vf)
 	gtk_box_pack_start(GTK_BOX(hbox), menubar, FALSE, TRUE, 0);
 	gtk_widget_show(menubar);
 
-	menuitem = gtk_menu_item_new_with_label(_("Class"));
-	gtk_widget_set_tooltip_text(GTK_WIDGET(menuitem), _("Select Class filter"));
-	gtk_menu_item_set_submenu(GTK_MENU_ITEM (menuitem), class_filter_menu(vf));
-	gtk_menu_shell_append(GTK_MENU_SHELL (menubar), menuitem);
-	gtk_widget_show(menuitem);
+	box = gtk_hbox_new(GTK_ORIENTATION_HORIZONTAL, PREF_PAD_GAP);
+	icon = gtk_image_new_from_icon_name("pan-down", GTK_ICON_SIZE_MENU);
+	label = gtk_label_new(_("Class"));
 
-	gtk_widget_show(menuitem);
+	gtk_box_pack_start(GTK_BOX(box), label, FALSE, FALSE, 0);
+	gtk_box_pack_end(GTK_BOX(box), icon, FALSE, FALSE, 0);
+
+	menuitem = gtk_menu_item_new();
+
+	gtk_widget_set_tooltip_text(GTK_WIDGET(menuitem), _("Select Class filter"));
+	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menuitem), class_filter_menu(vf));
+	gtk_menu_shell_append(GTK_MENU_SHELL(menubar), menuitem);
+	gtk_container_add(GTK_CONTAINER(menuitem), box);
+	gtk_widget_show_all(menuitem);
 
 	return frame;
 }
@@ -1243,7 +1266,7 @@ ViewFile *vf_new(FileViewType type, FileData *dir_fd)
 	vf->filter = vf_marks_filter_init(vf);
 	vf->file_filter.frame = vf_file_filter_init(vf);
 
-	vf->widget = gtk_vbox_new(FALSE, 0);
+	vf->widget = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	gtk_box_pack_start(GTK_BOX(vf->widget), vf->filter, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vf->widget), vf->file_filter.frame, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vf->widget), vf->scrolled, TRUE, TRUE, 0);
