@@ -99,7 +99,7 @@ typedef struct {
 	gint row;
 } ViewFileFindRowData;
 
-static gboolean vflist_find_row_cb(GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer data)
+static gboolean vflist_find_row_cb(GtkTreeModel *model, GtkTreePath *UNUSED(path), GtkTreeIter *iter, gpointer data)
 {
 	ViewFileFindRowData *find = data;
 	FileData *fd;
@@ -130,7 +130,7 @@ static gint vflist_find_row(ViewFile *vf, FileData *fd, GtkTreeIter *iter)
 	return -1;
 }
 
-static FileData *vflist_find_data_by_coord(ViewFile *vf, gint x, gint y, GtkTreeIter *iter)
+static FileData *vflist_find_data_by_coord(ViewFile *vf, gint x, gint y, GtkTreeIter *UNUSED(iter))
 {
 	GtkTreePath *tpath;
 	GtkTreeViewColumn *column;
@@ -153,7 +153,7 @@ static FileData *vflist_find_data_by_coord(ViewFile *vf, gint x, gint y, GtkTree
 	return NULL;
 }
 
-static gboolean vflist_store_clear_cb(GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer data)
+static gboolean vflist_store_clear_cb(GtkTreeModel *model, GtkTreePath *UNUSED(path), GtkTreeIter *iter, gpointer UNUSED(data))
 {
 	FileData *fd;
 	gtk_tree_model_get(model, iter, FILE_COLUMN_POINTER, &fd, -1);
@@ -218,9 +218,9 @@ static void vflist_move_cursor(ViewFile *vf, GtkTreeIter *iter)
  *-----------------------------------------------------------------------------
  */
 
-static void vflist_dnd_get(GtkWidget *widget, GdkDragContext *context,
-			   GtkSelectionData *selection_data, guint info,
-			   guint time, gpointer data)
+static void vflist_dnd_get(GtkWidget *UNUSED(widget), GdkDragContext *UNUSED(context),
+			   GtkSelectionData *selection_data, guint UNUSED(info),
+			   guint UNUSED(time), gpointer data)
 {
 	ViewFile *vf = data;
 	GList *list = NULL;
@@ -261,7 +261,7 @@ static void vflist_dnd_begin(GtkWidget *widget, GdkDragContext *context, gpointe
 		}
 }
 
-static void vflist_dnd_end(GtkWidget *widget, GdkDragContext *context, gpointer data)
+static void vflist_dnd_end(GtkWidget *UNUSED(widget), GdkDragContext *context, gpointer data)
 {
 	ViewFile *vf = data;
 
@@ -273,9 +273,9 @@ static void vflist_dnd_end(GtkWidget *widget, GdkDragContext *context, gpointer
 		}
 }
 
-static void vflist_drag_data_received(GtkWidget *entry_widget, GdkDragContext *context,
+static void vflist_drag_data_received(GtkWidget *UNUSED(entry_widget), GdkDragContext *UNUSED(context),
 				      int x, int y, GtkSelectionData *selection,
-				      guint info, guint time, gpointer data)
+				      guint info, guint UNUSED(time), gpointer data)
 {
 	ViewFile *vf = data;
 
@@ -366,7 +366,7 @@ GList *vflist_pop_menu_file_list(ViewFile *vf)
 }
 
 
-void vflist_pop_menu_view_cb(GtkWidget *widget, gpointer data)
+void vflist_pop_menu_view_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 
@@ -384,7 +384,7 @@ void vflist_pop_menu_view_cb(GtkWidget *widget, gpointer data)
 		}
 }
 
-void vflist_pop_menu_rename_cb(GtkWidget *widget, gpointer data)
+void vflist_pop_menu_rename_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 	GList *list;
@@ -415,7 +415,7 @@ void vflist_pop_menu_rename_cb(GtkWidget *widget, gpointer data)
 	file_util_rename(NULL, list, vf->listview);
 }
 
-void vflist_pop_menu_thumbs_cb(GtkWidget *widget, gpointer data)
+void vflist_pop_menu_thumbs_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 
@@ -465,7 +465,7 @@ void vflist_star_rating_set(ViewFile *vf, gboolean enable)
 	g_list_free(columns);
 }
 
-void vflist_pop_menu_show_star_rating_cb(GtkWidget *widget, gpointer data)
+void vflist_pop_menu_show_star_rating_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 
@@ -477,7 +477,7 @@ void vflist_pop_menu_show_star_rating_cb(GtkWidget *widget, gpointer data)
 	vflist_star_rating_set(vf, options->show_star_rating);
 }
 
-void vflist_pop_menu_refresh_cb(GtkWidget *widget, gpointer data)
+void vflist_pop_menu_refresh_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 
@@ -486,7 +486,7 @@ void vflist_pop_menu_refresh_cb(GtkWidget *widget, gpointer data)
 	gtk_tree_view_columns_autosize(GTK_TREE_VIEW(vf->listview));
 }
 
-void vflist_popup_destroy_cb(GtkWidget *widget, gpointer data)
+void vflist_popup_destroy_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 	vflist_color_set(vf, VFLIST(vf)->click_fd, FALSE);
@@ -501,7 +501,7 @@ void vflist_popup_destroy_cb(GtkWidget *widget, gpointer data)
  *-----------------------------------------------------------------------------
  */
 
-static gboolean vflist_row_rename_cb(TreeEditData *td, const gchar *old, const gchar *new, gpointer data)
+static gboolean vflist_row_rename_cb(TreeEditData *UNUSED(td), const gchar *old, const gchar *new, gpointer data)
 {
 	ViewFile *vf = data;
 	gchar *new_path;
@@ -530,7 +530,7 @@ static gboolean vflist_row_rename_cb(TreeEditData *td, const gchar *old, const g
 	return FALSE;
 }
 
-static void vflist_menu_position_cb(GtkMenu *menu, gint *x, gint *y, gboolean *push_in, gpointer data)
+static void vflist_menu_position_cb(GtkMenu *menu, gint *x, gint *y, gboolean *UNUSED(push_in), gpointer data)
 {
 	ViewFile *vf = data;
 	GtkTreeModel *store;
@@ -742,7 +742,7 @@ static void vflist_select_image(ViewFile *vf, FileData *sel_fd)
 	if (sel_fd == cur_fd) return; /* no change */
 
 	row = g_list_index(vf->list, sel_fd);
-	// FIXME sidecar data
+	/** @FIXME sidecar data */
 
 	if (sel_fd && options->image.enable_read_ahead && row >= 0)
 		{
@@ -791,23 +791,23 @@ static void vflist_select_idle_cancel(ViewFile *vf)
 		}
 }
 
-static gboolean vflist_select_cb(GtkTreeSelection *selection, GtkTreeModel *store, GtkTreePath *tpath,
-				 gboolean path_currently_selected, gpointer data)
+static gboolean vflist_select_cb(GtkTreeSelection *UNUSED(selection), GtkTreeModel *store, GtkTreePath *tpath, gboolean path_currently_selected, gpointer data)
 {
 	ViewFile *vf = data;
 	GtkTreeIter iter;
 	GtkTreePath *cursor_path;
 
-	gtk_tree_view_get_cursor(GTK_TREE_VIEW(vf->listview), &cursor_path, NULL);
-	if (cursor_path)
+	VFLIST(vf)->select_fd = NULL;
+
+	if (!path_currently_selected && gtk_tree_model_get_iter(store, &iter, tpath))
 		{
-		gtk_tree_model_get_iter(store, &iter, cursor_path);
-		gtk_tree_model_get(store, &iter, FILE_COLUMN_POINTER, &VFLIST(vf)->select_fd, -1);
-		gtk_tree_path_free(cursor_path);
-		}
-	else
-		{
-		VFLIST(vf)->select_fd = NULL;
+		gtk_tree_view_get_cursor(GTK_TREE_VIEW(vf->listview), &cursor_path, NULL);
+		if (cursor_path)
+			{
+			gtk_tree_model_get_iter(store, &iter, cursor_path);
+			gtk_tree_model_get(store, &iter, FILE_COLUMN_POINTER, &VFLIST(vf)->select_fd, -1);
+			gtk_tree_path_free(cursor_path);
+			}
 		}
 
 	if (vf->layout &&
@@ -819,13 +819,13 @@ static gboolean vflist_select_cb(GtkTreeSelection *selection, GtkTreeModel *stor
 	return TRUE;
 }
 
-static void vflist_expand_cb(GtkTreeView *tree_view, GtkTreeIter *iter, GtkTreePath *path, gpointer data)
+static void vflist_expand_cb(GtkTreeView *UNUSED(tree_view), GtkTreeIter *iter, GtkTreePath *UNUSED(path), gpointer data)
 {
 	ViewFile *vf = data;
 	vflist_set_expanded(vf, iter, TRUE);
 }
 
-static void vflist_collapse_cb(GtkTreeView *tree_view, GtkTreeIter *iter, GtkTreePath *path, gpointer data)
+static void vflist_collapse_cb(GtkTreeView *UNUSED(tree_view), GtkTreeIter *iter, GtkTreePath *UNUSED(path), gpointer data)
 {
 	ViewFile *vf = data;
 	vflist_set_expanded(vf, iter, FALSE);
@@ -1400,7 +1400,7 @@ gint vflist_index_by_fd(ViewFile *vf, FileData *fd)
 		work2 = list_fd->sidecar_files;
 		while (work2)
 			{
-			/* FIXME: return the same index also for sidecars
+			/** @FIXME return the same index also for sidecars
 			   it is sufficient for next/prev navigation but it should be rewritten
 			   without using indexes at all
 			*/
@@ -1673,6 +1673,31 @@ void vflist_select_by_fd(ViewFile *vf, FileData *fd)
 		}
 }
 
+void vflist_select_list(ViewFile *vf, GList *list)
+{
+	GtkTreeIter iter;
+	GList *work;
+
+	work = list;
+
+	while (work)
+		{
+		FileData *fd;
+
+		fd = work->data;
+
+		if (vflist_find_row(vf, fd, &iter) < 0) return;
+		if (!vflist_row_is_selected(vf, fd))
+			{
+			GtkTreeSelection *selection;
+
+			selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(vf->listview));
+			gtk_tree_selection_select_iter(selection, &iter);
+			}
+		work = work->next;
+		}
+}
+
 static void vflist_select_closest(ViewFile *vf, FileData *sel_fd)
 {
 	GList *work;
@@ -1923,8 +1948,8 @@ gboolean vflist_refresh(ViewFile *vf)
 		        }
 	        else
 			{
-			// FIXME: only do this when needed (aka when we just switched from
-			// FIXME: marks-enabled to marks-disabled)
+			/** @FIXME only do this when needed (aka when we just switched from */
+			/** @FIXME marks-enabled to marks-disabled) */
 			file_data_unlock_list(vf->list);
 			}
 
@@ -1991,7 +2016,7 @@ static GdkColor *vflist_listview_color_shifted(GtkWidget *widget)
 	return &color;
 }
 
-static void vflist_listview_color_cb(GtkTreeViewColumn *tree_column, GtkCellRenderer *cell,
+static void vflist_listview_color_cb(GtkTreeViewColumn *UNUSED(tree_column), GtkCellRenderer *cell,
 				     GtkTreeModel *tree_model, GtkTreeIter *iter, gpointer data)
 {
 	ViewFile *vf = data;
@@ -2128,7 +2153,7 @@ gboolean vflist_set_fd(ViewFile *vf, FileData *dir_fd)
 	return ret;
 }
 
-void vflist_destroy_cb(GtkWidget *widget, gpointer data)
+void vflist_destroy_cb(GtkWidget *UNUSED(widget), gpointer data)
 {
 	ViewFile *vf = data;
 
@@ -2142,7 +2167,7 @@ void vflist_destroy_cb(GtkWidget *widget, gpointer data)
 	filelist_free(vf->list);
 }
 
-ViewFile *vflist_new(ViewFile *vf, FileData *dir_fd)
+ViewFile *vflist_new(ViewFile *vf, FileData *UNUSED(dir_fd))
 {
 	GtkTreeStore *store;
 	GtkTreeSelection *selection;
